("\"encryption\" features from the preference panel" "Χαρακτηριστικά κρυπτογράφησης από τον πίνακα προτιμήσεων")
("(Re)Build autocompletion index" "(Επανα)Δημιουργία δείκτη αυτόματης συμπλήρωσης")
("a modifier" "τροποποιητής a")
("a series" "σειρά a")
("a.C.M. computing class" "Κλάση υπολογιστικής A.C.M.")
("a.M.S. subject class" "a.M.S. κλάση υποκειμένου")
("abbreviated authors" "συντομογραφημένοι συγγραφείς")
("abbreviation" "συντομογραφία")
("about" "σχετικά με το TeXmacs")
("about menu" "σχετικά με το μενού")
("above" "πάνω")
("abreviated authors" "συντομογραφημένοι συγγραφείς")
("abstract" "περίληψη")
("accent" "τόνος")
("accent above" "προφορά παραπάνω")
("accent below" "έμφαση κάτω από")
("accept" "αποδοχή")
("accept all scripts" "αποδοχή όλων των scripts")
("accept during this pass" "αποδοχή κατά τη διάρκεια αυτού του περάσματος")
("accept no scripts" "μη αποδοχή των scripts")
("accept script" "αποδοχή του scripts")
("acknowledgment" "ευχαριστία")
("acknowledgments" "ευχαριστίες")
("acronym" "ακρωνύμιο")
("action" "ενέργεια")
("activate" "ενεργοποίηση")
("activate hidden" "ενεργοποίηση  των κρυμμένων")
("activate once" "ενεργοποίηση μια φορά")
("activation" "ενεργοποίηση")
("active link types" "τύποι ενεργών συνδέσμων")
("acute" "οξεία")
("add" "προσθήκη")
("add abstract information" "προσθήκη πληροφοριών περίληψης")
("add author information" "Προσθήκη πληροφοριών συγγραφέα")
("add branch after" "προσθήκη κλάδου μετά")
("add branch before" "προσθήκη κλάδου πριν")
("add other package" "προσθήκη άλλου πακέτου")
("add package" "προσθήκη πακέτου")
("add style package" "προσθήκη πακέτου στυλ")
("add switch after" "προσθήκη διακόπτη μετά")
("add switch before" "προσθήκη διακόπτη πριν")
("add title information" "προσθήκη πληροφοριών τίτλου")
("addition" "Προσθήκη")
("address" "διεύθυνση")
("address block" "μπλοκ με διευθύνσεις")
("adjust" "προσαρμογή")
("adjust limits" "προσαρμογή ορίων")
("advanced" "για προχωρημένους")
("advanced font customization" "προηγμένη προσαρμογή γραμματοσειράς")
("advanced layout features" "προηγμένες λειτουργίες διάταξης")
("affiliation" "υπαγωγή")
("after" "μετά")
("albanian" "αλβανικά")
("algorithm" "αλγόριθμος")
("align cell to the bottom" "στοίχιση κελιού κάτω")
("align cell to the decimal comma" "ευθυγραμμίστε το κελί με το δεκαδικό κόμμα")
("align cell to the decimal dot" "ευθυγραμμίστε το κελί με την δεκαδική τελεία")
("align cell to the left" "στοίχιση κελιού αριστερά")
("align cell to the right" "στοίχιση κελιού δεξιά")
("align cell to the top" "στοίχιση κελιού πάνω")
("align table at axis" "ευθυγράμμιση πίνακα στον άξονα")
("align table at base of left column" "στοίχιση πίνακα στην βάση της αριστερής στήλης")
("align table at base of middle column" "στοίχιση πίνακα στην βάση της μεσαίας στήλης")
("align table at base of origin column" "στοίχιση πίνακα στην βάση της αρχικής στήλης")
("align table at base of right column" "στοίχιση πίνακα στην βάση της δεξιάς στήλης")
("align table at fraction bar height" "στοίχιση πίνακα στο ύψος της γραμμής κλάσματος")
("align table at the base of bottom row" "στοίχιση πίνακα στην βάση της κάτω σειράς")
("align table at the base of middle row" "στοίχιση πίνακα στην βάση της μεσαίας σειράς")
("align table at the base of origin row" "στοίχιση πίνακα στην βάση της αρχικής σειράς")
("align table at the base of top row" "στοίχιση πίνακα στην βάση της πάνω σειράς")
("align table at the bottom" "στοίχιση πίνακα κάτω")
("align table at the center" "στοίχιση πίνακα στο κέντρο")
("align table at the horizontal center" "στοίχιση πίνακα στο κέντρο οριζοντίως")
("align table at the left" "στοίχιση πίνακα αριστερά")
("align table at the top" "στοίχιση πίνακα πάνω")
("align table to the right" "στοίχιση πίνακα δεξιά")
("align text to the left" "στοίχιση κειμένου αριστερά")
("align text to the right" "στοίχιση κειμένου δεξιά")
("aligned" "στοιχισμένο")
("alignment" "στοίχιση")
("alignment of balloon" "ευθυγράμμιση του μπαλονιού")
("all" "όλα")
("all cells" "όλα τα κελιά")
("all data attached to this identity will be lost" "όλα τα δεδομένα που συνδέονται με αυτήν την ταυτότητα θα χαθούν")
("all saved passphrases will be lost forever" "όλες οι αποθηκευμένες φράσεις πρόσβασης θα χαθούν για πάντα")
("allow" "αποδοχή")
("allow for macro definitions in preamble" "επιτρεπτός ο ορισμός μακροεντολών στο προοίμιο")
("allowed extension" "επιτρεπτή επέκταση")
("allowed page height extension" "επιτρέπεται επέκταση ύψους σελίδας")
("allowed page height reduction" "επιτρέπεται μείωση ύψους σελίδας")
("allowed positions" "επιτρεπόμενες θέσεις")
("allowed positions of floating object" "επιτρεπόμενες θέσεις πλωτού αντικειμένου")
("allowed reduction" "επιτρεπτή μείωση")
("alpha release" "δοκιμαστική έκδοση alpha")
("alpha transparency" "Διαφάνεια άλφα")
("also on paper" "επίσης σε χαρτί")
("alt key" "πλήκτρο Alt")
("alter" "τροποποίηση")
("alternate" "εναλλακτικά")
("alternate except here" "εναλλαγή εκτός από εδώ")
("alternate from here on" "εναλλαγή από εδώ και πέρα")
("alternate only here" "εναλλαγή μόνο εδώ")
("alternate until here" "εναλλαγή μέχρι εδώ")
("alternative specification" "εναλλακτική προδιαγραφή")
("always" "πάντα")
("american" "αμερικανικά")
("amplified" "Ενισχυμένο")
("and" "και")
("and perform casual settings from the \"Encryption\" tab" "και να εκτελέσετε τυχαίες ρυθμίσεις από την καρτέλα \"Κρυπτογράφηση\"")
("angular" "γωνιακή")
("animate" "κινούμενα")
("animate folding" "κινούμενη αναδίπλωση")
("animate unfolding" "κινούμενο ξεδίπλωμα")
("animated" "κινούμενα")
("animation" "κινησιοδότηση")
("animation toolbar" "γραμμή εργαλείων κίνησης")
("annotate" "σχολιασμός")
("answer" "απάντηση")
("answer field" "Πεδίο απάντησης")
("answer to question" "Απάντηση στην ερώτηση")
("answers only" "Μόνο απαντήσεις")
("any" "οποιοδήποτε")
("appear" "εμφανίζονται")
("appendix" "παράρτημα")
("apply" "εφαρμογή")
("apply macro" "εφαρμογή μακροεντολής")
("apply macro once" "εφαρμογή μακροεντολής μια φορά")
("approximate" "κατά προσέγγιση")
("april" "απρίλιος")
("arab" "αραβικά")
("arc" "τόξο")
("arc cosine" "τόξο συνημιτόνου")
("arc sine" "τόξο ημιτόνου")
("arc tangent" "τόξο εφαπτομένης")
("arch series" "σειρά αψίδων")
("archaic" "αρχαϊκά")
("architecture" "αρχιτεκτονική")
("are you sure you want to delete collected public keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε τα συλλεγμένα δημόσια κλειδιά")
("are you sure you want to delete selected public keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε επιλεγμένα δημόσια κλειδιά")
("are you sure you want to delete selected secret keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε επιλεγμένα μυστικά κλειδιά")
("are you sure you want to destroy the wallet" "είστε βέβαιοι ότι θέλετε να καταστρέψετε το πορτοφόλι")
("argument" "όρισμα")
("arithmetic" "αριθμητικό")
("armenian" "αρμενικά")
("arrow" "βέλος")
("arrows" "βέλη")
("art frame" "πλαίσιο τέχνης")
("article" "άρθρο")
("arxiv category" "Κατηγορία arxiv")
("as on paper" "όπως στο χαρτί")
("as visual grid" "ως οπτικό πλέγμα")
("aspect" "πτυχή")
("assign" "ανάθεση")
("at fraction bar height" "στο ύψος της γραμμής κλάσματος")
("at the baseline" "στη γραμμή βάσης")
("at the bottom" "κάτω")
("at the left" "αριστερά")
("at the middle" "στη μέση")
("at the right" "δεξιά")
("at the top" "πάνω")
("attach" "επισύναψη")
("attach buffer to which project" "επισύναψη προσωρινής αποθήκευσης σε ποιο έργο")
("attach master" "επισύναψη πρωτοτύπου")
("august" "αύγουστος")
("author" "συγγραφέας")
("authorize" "εξουσιοδότηση")
("auto" "αυτόματα")
("auto-save file" "Αρχείο αυτόματης αποθήκευσης")
("automatic" "αυτόματα")
("automatic brackets" "αυτόματες αγκύλες")
("automatic content generation" "αυτόματη δημιουργία περιεχομένου")
("automatic program brackets" "αυτόματες αγκύλες προγράμματος")
("automatic quotes" "αυτόματα  εισαγωγικά")
("automatically close brackets" "αυτόματο κλείσιμο παρενθέσεων")
("automatically generated content" "αυτόματη δημιουργία περιεχομένου")
("automatically import bibliographies when opening files" "αυτόματη εισαγωγή βιβλιογραφιών κατά το άνοιγμα αρχείων")
("automatically remember all passphrases in the wallet" "αυτόματη διατήρηση όλων των φράσεων πρόσβασης στο πορτοφόλι")
("automatically save" "αυτόματη αποθήκευση")
("autosave" "αυτόματη αποθήκευση")
("axiom" "αξίωμα")
("axis" "άξονας")
("b series" "σειρά b")
("back" "πίσω")
("background" "φόντο")
("background color" "χρώμα του φόντου")
("background evaluations" "αξιολογήσεις ιστορικού")
("backtrace errors" "ιχνηλάτηση σφαλμάτων")
("backward replace" "αντικατάσταση προς τα πίσω")
("backward search" "αναζήτηση προς τα πίσω")
("bad data format" "λανθασμένη μορφή δεδομένων")
("bar" "γραμμή")
("bard" "bard")
("base" "βάση")
("base level" "επίπεδο βάσης")
("baseline" "αρχική τιμή")
("bashkirian" "bashkirian")
("basic" "βασικό")
("basic communication using pipes" "βασικές επικοινωνία με τη χρήση σωλήνων")
("basic data types" "βασικοί τύποι δεδομένων")
("basic types" "βασικοί τύποι")
("be useful" "γίνετε χρήσιμος")
("beamer" "beamer")
("beamer formats" "Μορφές beamer")
("beamer theme" "Θέμα beamer")
("become a TeXmacs developer" "γίνετε ένας προγραμματιστής του TeXmacs")
("before" "πριν")
("begin" "αρχή")
("below" "κάτω")
("bench" "πάγκος")
("bend bottom" "καμπύλο κάτω μέρος")
("bend corner" "καμπύλη γωνία")
("bend diagonal" "καμπύλη διαγώνιος")
("bend in" "κάμψη μέσα")
("bend out" "κάμψη έξω)")
("beta release" "δοκιμαστική έκδοση beta")
("bezier" "bezier")
("bibTeX command" "Εντολή bibTeX")
("bibliography" "βιβλιογραφία")
("bibliography file" "αρχείο βιβλιογραφίας")
("bibliography style" "στυλ βιβλιογραφίας")
("bidirectional" "αμφίδρομη")
("big" "μεγάλο")
("big environment box" "μεγάλο πλαίσιο περιβάλλοντος")
("big figure" "μεγάλο σχήμα")
("big focus" "μεγάλη εστίαση")
("big operator" "μεγάλος τελεστής")
("big skip" "μεγάλο κενό")
("big table" "μεγάλος πίνακας")
("binary operation" "δυαδική πράξη")
("binary operator" "δυαδικός τελεστής")
("binary relation" "δυαδική σχέση")
("bitmap resolution (dpi)" "ανάλυση bitmap (dpi)")
("black" "μαύρο")
("black floral I" "μαύρο λουλουδάτο I")
("black floral II" "μαύρο λουλουδάτο II")
("blackboard bold" "γραμματοσειρά blackboard bold")
("blackboard embold" "έντονο μαύρο σαν μαυροπίνακα")
("blackboard math" "γραμματοσειρά blackboard math")
("blackletter" "γραμματοσειρά blackletter")
("blank column" "κενή στήλη")
("blank row" "κενή γραμμή")
("block" "μπλοκ")
("block content" "μπλοκ περιεχομένου")
("block of code" "μπλοκ κώδικα")
("blue" "μπλε")
("blur" "θαμπάδα")
("body" "σώμα")
("bold" "bold")
("book" "βιβλίο")
("border" "περίγραμμα")
("both" "και τα δύο")
("both versions" "και οι δύο εκδόσεις")
("bottom" "κάτω")
("bottom baseline" "γραμμή βάσης στο κάτω μέρος")
("bottom border" "κάτω περίγραμμα")
("bottom cell border" "κάτω περίγραμμα του κελιού")
("bottom cell padding" "κάτω αναπλήρωση του κελιού")
("bottom margin" "κάτω περιθώριο")
("bottom padding" "αναπλήρωση κάτω")
("bottom table border" "κάτω περίγραμμα του πίνακα")
("bottom table padding" "κάτω αναπλήρωση πίνακα")
("bottom tools" "εργαλεία κάτω")
("box" "κουτί")
("branch" "κλάδος")
("break" "αλλαγή")
("breaking" "αλλάζοντας")
("breve" "breve")
("british" "βρετανικά")
("broken white" "σπασμένο λευκό")
("brown" "καφέ")
("browse" "περιήγηση")
("browse back" "περιήγηση προς τα πίσω")
("browse forward" "περιήγηση προς τα εμπρός")
("browse modules documentation" "περιήγηση στην τεκμηρίωση μονάδων")
("browse web" "περιήγηση ιστού")
("browser" "φυλλομετρητής")
("buffer" "προσωρινή αποθήκευση")
("buffer management" "διαχείριση buffer")
("buffer must be on disk" "buffer πρέπει να είναι στο δίσκο")
("buffer must have a name" "buffer πρέπει να έχει όνομα)")
("build buffer" "δημιουργία buffer")
("build buffer in" "δημιουργία buffer σε")
("build directory" "δημιουργία καταλόγου")
("build directory in" "δημιουργία καταλόγου σε")
("build link pages" "δημιουργία σελίδων συνδέσμων")
("build-all" "δημιουργία όλων")
("bulgarian" "βουλγαρικά")
("bullet" "κουκίδα")
("bullets" "κουκίδες")
("bump" "χτύπημα")
("busy" "απασχολημένος")
("by" "από")
("by typing" "πληκτρολογώντας")
("bytes free" "ελεύθερα bytes")
("bytes used" "bytes που χρησιμοποιούνται")
("cJK" "cJK")
("cJK spacing" "Απόσταση CJK")
("calculus" "λογισμός")
("calligraphic" "καλλιγραφικά")
("cancel" "ακύρωση")
("cancelled" "ακυρώθηκε")
("cannot download directory to file" "δεν είναι δυνατό το κατέβασμα του καταλόγου σε αρχείο")
("cannot rename across different servers" "δεν είναι δυνατή η μετονομασία σε διαφορετικούς διακομιστές")
("cannot upload directory to file" "δεν είναι δυνατό το ανέβασμα του καταλόγου σε αρχείο")
("caps-lock key" "πλήκτρο caps-lock")
("cartesian" "καρτεσιανό")
("carved wood" "σκαλιστό ξύλο")
("case" "πεζά/κεφαλαία")
("case-insensitive search" "αναζήτηση χωρίς διάκριση μικρών / κεφαλαίων")
("categories" "Κατηγορίες")
("category" "Κατηγορία")
("cc" "αντίγραφο")
("cell" "κελί")
("cell background color" "χρώμα φόντου κελιού")
("cell border" "περίγραμμα κελιού")
("cell height" "ύψος κελιού")
("cell operation mode" "τύπος λειτουργίας κελιού")
("cell properties" "ιδιότητες κελιών")
("cell width" "πλάτος κελιού")
("cells" "κελιά")
("center" "κέντρο")
("center text" "κεντράρισμα κειμένου")
("centered" "κεντραρισμένο")
("centered block" "κεντραρισμένο μπλοκ")
("centered tabular" "κεντραρισμένος πίνακας δεδομένων")
("change border of cell" "αλλαγή περιγράμματος κελιού")
("change cell operation mode" "αλλαγή τύπου λειτουργίας κελιού")
("change default unit" "αλλαγή της προεπιλεγμένης μονάδας")
("change log" "καταγραφή αλλαγών ")
("change passphrase" "αλλαγή φράσης πρόσβασης")
("change step-size" "αλλαγή μεγέθους βήματος")
("change tags" "αλλαγή ετικετών")
("change the TeXmacs preferences" "αλλαγή προτιμήσεων του TeXmacs")
("change the border of the table" "αλλαγή του περιγράμματος πίνακα")
("change the style of mathematical formulas" "αλλαγή στο στυλ των μαθηματικών τύπων")
("changes" "αλλαγές")
("chapter" "κεφάλαιο")
("character contraction" "Συστολή χαρακτήρων")
("character encoding" "Κωδικοποίηση χαρακτήρων")
("character expansion" "Επέκταση χαρακτήρων")
("check" "έλεγχος")
("check for updates" "έλεγχος για ενημερώσεις")
("check text for spelling errors" "ορθογραφικός έλεγχος κειμένου")
("checkable field" "ελέγξιμο πεδίο")
("chinese" "κινέζικα")
("choice" "επιλογή")
("cipher algorithm for passphrase encryption" "αλγόριθμος κωδικοποίησης για κρυπτογράφηση φράσης πρόσβασης")
("circle" "κύκλος")
("citation" "παραπομπή")
("cite" "αναφορά")
("class" "κλάση")
("classification" "ταξινόμηση")
("clean slate" "λευκό μητρώο")
("clear" "εκκαθάριση")
("clear all fields" "εκκαθάριση όλων των πεδίων")
("clear local information" "εκκαθάριση τοπικών πληροφοριών")
("clear menu" "εκκαθάριση μενού")
("clear selection" "εκκαθάριση επιλογής")
("clear undo history" "εκκαθάριση ιστορικού αναίρεσης")
("click Ok button twice to discard this warning" "πατήστε το κουμπί Ok δύο φορές για να απορρίψετε αυτήν την προειδοποίηση")
("clip" "απόσπασμα")
("clipboard image format" "μορφή εικόνας πρόχειρου")
("clipped" "αποκομμένο")
("clipped and magnified" "αποκομμένο και μεγενθυμένο")
("clipped and resized" "αποκομμένο και με αλλαγμένο μέγεθος")
("clone" "κλωνοποίηση")
("clone window" "κλωνοποίηση παραθύρου")
("close" "κλείσιμο")
("close TeXmacs" "κλείσιμο TeXmacs")
("close animation tool" "κλείσιμο εργαλείου κινούμενων σχεδίων")
("close buffer" "κλείσιμο προσωρινής αποθήκευσης")
("close document" "κλείσιμο  εγγράφου")
("close program" "κλείσιμο προγράμματος")
("close replace tool" "κλείσιμο εργαλείου αντικατάστασης")
("close search tool" "κλείσιμο εργαλείου αναζήτησης")
("close session" "κλείσιμο συνεδρίας")
("close spell tool" "κλείσιμο εργαλείου ορθογραφίας")
("close translations to rebuild" "κλείσιμο μεταφράσεων για αναδημιουργία")
("close window" "κλείσιμο παραθύρου")
("closed bezier" "κλειστή καμπύλη bezier")
("closed curve" "κλειστή καμπύλη")
("closed smooth" "κλειστή λεία")
("closed spline" "κλειστή καμπύλη spline")
("closing" "κλείσιμο")
("closing style" "στυλ κλεισίματος")
("cluster by affiliation" "ομαδοποίηση κατά συνεργασία")
("code" "code")
("collect garbage" "συλλογή σκουπιδιών")
("collected keys" "συλλεγμένα κλειδιά")
("color" "χρώμα")
("color of the axes" "χρώμα των αξόνων")
("color of the subunits" "χρώμα των υπομονάδων")
("color of the units" "χρώμα των μονάδων")
("colors" "χρώματα")
("column" "στήλη")
("column contains glued items" "η στήλη περιέχει επικολλημένα στοιχεία")
("column separation" "Διαχωρισμός στήλης")
("column to the left" "στήλη προς τα αριστερά")
("column to the right" "στήλη προς τα δεξιά")
("columns" "στήλες")
("commit file" "δέσμευση αρχείου")
("common" "κοινό")
("common formats" "συνηθισμένες μορφές")
("commutative diagram" "αντιμεταθετικό διάγραμμα")
("compact" "compact")
("compactification" "συμπαγοποίηση")
("compactify" "συμπαγοποίηση")
("compatibility with other formats" "συμβατότητα με άλλες μορφές")
("compile article" "μεταγλώττιση άρθρου")
("compile book" "μεταγλώττιση βιβλίου")
("compile buffer" "μεταγλώττιση προσωρινής αποθήκευσης")
("compile project" "μεταγλώττιση έργου")
("complete bibliographic reference" "πλήρης βιβλιογραφική αναφορά")
("completion" "περάτωση")
("complex" "μιγαδικοί")
("complex actions" "σύνθετες ενέργειες")
("compose" "σύνθεση")
("compound" "ένωση")
("compress" "συμπίεση")
("compress into toolbar" "συμπίεση στη γραμμή εργαλείων")
("compressed" "compressed")
("conceal" "κρύβουν")
("concrete" "concrete")
("condensed" "condensed")
("condition" "προϋπόθεση")
("configuration" "ρύθμιση")
("configure look and feel" "ρυθμίστε την εμφάνιση και την αίσθηση")
("confirm database entry" "επιβεβαίωση εγγραφής βάσης δεδομένων")
("confirm entry" "Επιβεβαίωση εγγραφής")
("confirm selected database entries" "επιβεβαίωση επιλεγμένων καταχωρίσεων βάσης δεδομένων")
("confirm selected entries" "επιβεβαίωση επιλεγμένων καταχωρήσεων")
("conservative conversion options" "συντηρητικές επιλογές μετατροπής")
("consoles" "κονσόλες")
("constants" "σταθερές")
("constellation" "αστερισμός")
("contact" "επαφή")
("content" "περιεχόμενο")
("content tag" "είδος γραμματοσειράς")
("context aids" "βοηθήματα περιβάλλοντος")
("context dependent icons" "εικονίδια εξαρτόμενα από τα συμφραζόμενα")
("contextual hints" "συμβουλές συμφραζομένων")
("continuation of" "συνέχεια")
("continue" "συνέχεια")
("continued fraction" "συνεχές κλάσμα")
("contour" "περίγραμμα")
("contract logarithms" "συστολή λογαρίθμων")
("contribute" "συνεισφορά")
("control flow" "έλεγχος ροής")
("control the evaluation of expressions" "έλεγχος αποτίμησης παραστάσεων")
("convention" "σύμβαση")
("convert" "μετατροπή")
("converters" "μετατροπείς")
("converters to other data formats" "μετατροπείς σε άλλη μορφή δεδομένων")
("convertible" "μετατρέψιμη")
("copy" "αντιγραφή")
("copy text" "αντιγραφή κειμένου")
("copy to" "αντιγραφή σε")
("copying" "αντιγραφή")
("copyright" "πνευματικά δικαιώματα")
("cork charset with TeX catcode definition in preamble" "χαρακτήρες Cork με TeX catcode ορισμό στο προοίμιο")
("corollary" "πόρισμα")
("correct" "σωστό")
("correct all" "διόρθωση όλων")
("correct formula" "διόρθωση φόρμουλας")
("correct manually" "διόρθωση με το χέρι")
("correct mathematical formulas" "διόρθωση μαθηματικών τύπων")
("correct text" "διόρθωση κειμένου")
("correction" "διόρθωση")
("cosine" "συνημίτονο")
("count characters" "μέτρημα χαρακτήρων")
("count lines" "μέτρημα γραμμών")
("count words" "μέτρημα λέξεων")
("create a new document" "δημιουργία νέου εγγράφου")
("create link" "δημιουργία συνδέσμου")
("create preamble" "δημιουργία προοιμίου")
("create remote directory" "δημιουργία απομακρυσμένου καταλόγου")
("create remote file" "Δημιουργία απομακρυσμένου αρχείου")
("create subprogram" "δημιουργία υποπρογράμματος")
("create subsession" "δημιουργία υποσυνεδρίας")
("create table macro" "δημιουργία πίνακα macro")
("create web site" "δημιουργία ιστοσελίδας")
("creating new account" "δημιουργία νέου λογαριασμού")
("creating technical pictures" "δημιουργία τεχνικών εικόνων")
("crop" "περικοπή")
("crop marks" "περικοπή σημαδιών")
("cross" "σταυρός")
("crossed boxes" "τσεκαρισμένα κουτιά")
("crossed circles" "τεμνόμενοι κύκλοι")
("current user version" "τρέχουσα έκδοση χρήστη")
("current version" "τρέχουσα έκδοση")
("cursor" "δρομέας")
("cursors" "δείκτες")
("curve" "καμπύλη")
("curve intersections" "διασταυρώσεις καμπύλης")
("curve points" "σημεία καμπύλης")
("custom tab" "προσαρμοσμένη καρτέλα")
("customizations" "προσαρμογές")
("customizing TeXmacs" "προσαρμογή του TeXmacs")
("customizing and extending the user interface" "προσαρμογή και επέκταση του περιβάλλοντος χρήστη")
("customizing the TeXmacs styles" "προσαρμόζοντας τα στυλ του TeXmacs")
("custum tab" "custum tab")
("cut" "αποκοπή")
("cut text" "αποκοπή κειμένου")
("cut to" "αποκοπή μέχρι")
("cypriot" "κυπριακά")
("cyrillic" "κυριλλικά")
("cyrillic input method" "μέθοδος εισόδου κυριλλικών")
("cyrillic italic right" "κυριλλικά σε italic")
("czech" "τσέχικα")
("dancers" "χορευτές")
("danish" "δανικά")
("dark grey" "σκούρο γκρι")
("dash" "παύλα")
("dashes" "παύλες")
("data" "δεδομένα")
("data conversion" "μετατροπή δεδομένων")
("data format" "μορφή δεδομένων")
("database entry" "καταχώρηση βάσης δεδομένων")
("database tool" "εργαλείο βάσης δεδομένων")
("database toolbar" "γραμμή εργαλείων βάσης δεδομένων")
("date" "ημερομηνία")
("deactivate" "απενεργοποίηση")
("deactivate once" "απενεργοποίηση μια φορά")
("deactivate table" "απενεργοποίηση πίνακα")
("dead" "νεκρό")
("debug" "αποσφαλμάτωση")
("debugging console" "κονσόλα αποσφαλμάτωσης")
("debugging tool" "εργαλείο αποσφαλμάτωσης")
("december" "δεκέμβριος")
("decimal comma" "δεκαδικό κόμμα")
("decimal dot" "δεκαδικό στίγμα")
("decomposed" "αποσύνθεση")
("decorate atoms" "decorate atoms")
("decorated" "διακοσμημένα")
("decorated wood" "διακοσμημένο ξύλο")
("decrease size" "μείωση μεγέθους")
("decrypt" "αποκρυπτογράφηση")
("default" "προεπιλογή")
("default padding" "προεπιλεγμένη αναπλήρωση")
("default size" "προεπιλεγμένο μέγεθος")
("definition" "ορισμός")
("degrade" "υποβάθμιση")
("degraded" "υποβαθμισμένο")
("delete" "διαγραφή")
("delete column" "διαγραφή στήλης")
("delete documentation cache" "διαγραφή της προσωρινής μνήμης τεκμηρίωσης")
("delete entries" "Διαγραφή καταχωρήσεων")
("delete link" "διαγραφή συνδέσμου")
("delete row" "διαγραφή σειράς")
("deleted" "διαγραμμένο")
("denominator" "παρονομαστής")
("describe" "περιγραφή")
("describe tag" "ετικέτα περιγραφής")
("description" "περιγραφή")
("destination" "προορισμός")
("destroy" "καταστροφή")
("detach" "απόσπαση")
("detach master" "αποσύνδεση πρωτοτύπου")
("detailed" "λεπτομερής ")
("detailed menus" "λεπτομερές μενού")
("details in menus" "λεπτομέρειες στα μενού")
("determinant" "ορίζουσα")
("determine margins from text width" "καθορισμός περιθωρίων από το πλάτος κειμένου")
("devangari" "devangari")
("developer" "προγραμματιστής")
("developer tool" "εργαλείο προγραμματιστή")
("developers guide" "οδηγός για προγραμματιστές")
("device" "Συσκευή")
("diamond" "διαμάντι")
("differentiate" "διαφόριση")
("dilate" "διαστολή")
("direction of progression" "κατεύθυνση της εξέλιξης")
("direction of translation" "κατεύθυνση μετάφρασης")
("directory" "κατάλογος")
("disable" "απενεργοποίηση")
("disable coloring on paper" "απενεργοποιήστε το χρωματισμό σε χαρτί")
("disable encryption" "απενεργοποίηση κρυπτογράφησης")
("disable first indentation" "απενεργοποίηση πρώτης εσοχής")
("disable first indentation after" "απενεργοποίηση πρώτης εσοχής μετά")
("disable first indentation before" "απενεργοποίηση πρώτης εσοχής πριν")
("disable indentation" "απενεργοποίηση εσοχής")
("disable indentation after" "απενεργοποίηση πρώτης εσοχής μετά")
("disable indentation before" "απενεργοποίηση πρώτης εσοχής πριν")
("disallow" "απαγόρευση")
("disappear" "εξαφάνιση")
("disk" "δίσκος")
("display style" "στυλ εμφάνισης")
("displayed formula" "αυτοτελής τύπος")
("dissociate joined cells" "αποσύνδεση ενωμένων κελιών")
("distort" "στρέβλωση")
("distorted" "διαστρεβλωμένο")
("distribute unused space" "διανομή αχρησιμοποίητου χώρου")
("div" "div")
("division" "διαίρεση")
("do not remap" "μην ξανα-απεικονίζεις")
("document" "έγγραφο")
("document font selector" "επιλογέας γραμματοσειράς εγγράφου")
("document format" "μορφοποίηση εγγράφου")
("document language" "γλώσσα εγγράφου")
("document page format" "μορφή σελίδας εγγράφου")
("document paragraph format" "μορφή παραγράφου εγγράφου")
("document style" "στυλ εγγράφου")
("document styles" "στυλ εγγράφου")
("document updates run" "είναι σε εξέλιξη ενημερώσεις εγγράφων")
("documentation" "τεκμηρίωση")
("documents are trees" "τα έγγραφα είναι δενδρα")
("dot" "τελεία")
("dots" "τελείες")
("double stroke" "διπλή μολυβιά")
("down" "κάτω")
("download" "λήψη")
("downwards" "προς τα κάτω")
("dpi" "dpi")
("dragging" "σύρσιμο")
("draw image" "σχεδιασμός εικόνας")
("draw over" "σχεδιασμός πάνω")
("draw over selection" "σχεδιασμός πάνω από την επιλογή")
("drop" "Πτώση")
("due to" "λόγω")
("duplicate" "αναπαραγωγή")
("dutch" "ολανδικά")
("dynamic" "δυναμική")
("dynamic libraries" "δυναμικές βιβλιοθήκες")
("eRROR" "eRROR")
("edit" "επεξεργασία")
("edit animation" "επεξεργασία κινούμενης εικόνας")
("edit groups of objects" "επεξεργασία ομάδων αντικειμένων")
("edit macro" "επεξεργασία μακροεντολής")
("edit macros" "επεξεργασία μακροεντολών")
("edit preamble" "επεξεργασία προοιμίου")
("edit source" "επεξεργασία πηγαίου κώδικα")
("edit source tree" "επεξεργασία πηγαίου δέντρου")
("edit style" "επεξεργασία στυλ")
("edit translations file" "επεξεργασία αρχείων μεταφράσεων")
("editing tools" "εργαλεία επεξεργασίας")
("education" "εκπαίδευση")
("effect pen" "Στυλό")
("eigenvalues" "ιδιοτιμές")
("eigenvectors" "ιδιοδιανύσματα")
("eighth" "όγδοο")
("elementary functions" "στοιχειώδεις συναρτήσεις")
("email" "ηλεκτρονικό ταχυδρομείο")
("embold" "embold")
("emboss" "ανάγλυφο")
("emphasize" "έμφαση")
("emphasize text" "έμφαση στο κείμενο")
("empty box" "άδειο κουτί")
("enable first indentation" "ενεργοποίηση πρώτης εσοχής")
("enable first indentation after" "ενεργοποίηση πρώτης εσοχής μετά")
("enable first indentation before" "ενεργοποίηση πρώτης εσοχής πριν")
("enable indentation" "ενεργοποίηση εσοχής")
("enable indentation after" "ενεργοποίηση εσοχής μετά")
("enable indentation before" "ενεργοποίηση εσοχής πριν")
("enable page breaking" "ενεργοποίηση σπασίματος σελίδας")
("encl" "συνημμένο")
("encoding" "κωδικοποίηση")
("encrypt" "κρυπτογράφηση")
("encryption" "κρυπτογράφηση")
("encryption facilities are not currently available" "υπηρεσίες κρυπτογράφησης δεν είναι επί του παρόντος διαθέσιμες")
("encryption facilities have not been enabled for TeXmacs" "Δεν έχουν ενεργοποιηθεί οι υπηρεσίες κρυπτογράφησης για την TeXmacs")
("end" "τέλος")
("enforce brackets to match" "επιβολή αντιστοίχησης αγκύλων")
("english" "αγγλικά")
("engrave" "χάραξη")
("enter a title" "εισαγωγή τίτλου")
("enter data" "εισαγωγή δεδομένων")
("enter graphics" "εισαγωγή γραφικών")
("enter graphics mode" "είσοδος στη λειτουργία γραφικών")
("enter new passphrase for encryption" "είσοδος νέας φράσης πρόσβασης για κρυπτογράφηση")
("enter passphrase for decryption" "είσοδος φράσης πρόσβασης για αποκρυπτογράφηση")
("enter passphrase for identity" "είσοδος φράσης πρόσβασης για ταυτοποίηση")
("enter title information" "είσοδος πληροφοριών τίτλου")
("entire table" "όλον τον πίνακα")
("entry up to date in database" "ενημερωμένη καταχώρηση στη βάση δεδομένων")
("enumerate" "απαρίθμηση")
("enumerate|Alpha" "απαρίθμηση|Alpha")
("enumerate|Roman" "απαρίθμηση|Roman")
("enumerate|alpha" "απαρίθμηση|alpha")
("enumerate|roman" "απαρίθμηση|roman")
("enunciation" "διατύπωση")
("env" "env")
("environment" "περιβάλλον")
("environment variable" "μεταβλητή περιβάλλοντος")
("environments" "περιβάλλοντα")
("epilogue" "επίλογος")
("equal" "ίσο")
("equation" "εξίσωση")
("equations" "εξισώσεις")
("equivalent for" "ισοδύναμο για")
("erode" "διάβρωση")
("error" "σφάλμα")
("error messages" "μηνύματα σφάλματος")
("error output" "Έξοδος σφάλματος")
("error status report" "αναφορά κατάστασης σφάλματος")
("error: bracket does not match" "σφάλμα: η αγκύλη δεν ταιριάζει")
("error: cyclic or missing chunks detected" "σφάλμα: ανίχνευση κυκλικών ή απόντων κομματιών")
("error: file not found" "σφάλμα: το αρχείο δεν βρέθηκε")
("error: ghostview does not seem to be installed on your system" "σφάλμα: το ghostview δεν φαίνεται να είναι εγκατεστημένο στο σύστημά σας")
("error: one of the alternatives should be filled out" "σφάλμα: μία από τις εναλλακτικές λύσεις θα πρέπει να συμπληρωθεί")
("error: only one alternatives should be filled out" "σφάλμα: πρέπει να συμπληρωθεί μόνο μία εναλλακτική λύση")
("error: should fill out name for referencing" "σφάλμα: πρέπει να συμπληρώσετε το όνομα για την αναφορά")
("error: should fill out required field" "σφάλμα: πρέπει να συμπληρωθεί το απαιτούμενο πεδίο")
("esperanto" "εσπεράντο")
("etruscan" "ετρουσκικά")
("evaluable field" "εκτιμητέο πεδίο")
("evaluate" "αποτίμηση")
("evaluate above" "αποτίμηση πάνω")
("evaluate all" "αποτίμηση όλων")
("evaluate below" "αποτίμηση κάτω")
("evaluate fields" "αξιολόγηση πεδίων")
("evaluate fields in order" "αποτίμηση πεδίων με την σειρά")
("evaluate scheme expression" "αποτίμηση παράστασης σε scheme")
("evaluate script" "αξιολόγηση δέσμης ενεργειών")
("evaluation" "αξιολόγηση")
("evaluation switch" "διακόπτης αποτίμησης")
("evaluation tag" "καρτέλα αποτίμησης")
("even page" "ζυγή σελίδα")
("even page footer" "υποσέλιδο σελίδας με άρτιο αριθμό")
("even page header" "κεφαλίδα σελίδας με άρτιο αριθμό")
("even page left margin" "αριστερό περιθώριο σελίδας με άρτιο αριθμό")
("even page margin" "περιθώριο σελίδας με άρτιο αριθμό")
("even page shift" "μετατόπιση σελίδας με άρτιο αριθμό")
("even page text" "κείμενο σελίδας με άρτιο αριθμό")
("even pages" "ζυγές σελίδες")
("events" "γεγονότα")
("exact" "ακριβές")
("exact horizontal" "ακριβής οριζόντιος")
("exact mode" "ακριβής λειτουργία")
("exam" "εξέταση")
("example" "παράδειγμα")
("exclusive" "αποκλειστικό")
("exclusive or" "αποκλειστικό ή")
("executable" "εκτελέσιμο")
("execute" "εκτέλεση")
("execute a TeXmacs command" "εκτέλεση εντολής TeXmacs")
("execute system command" "εκτέλεση εντολής συστήματος")
("execution of scripts" "εκτέλεση δεσμών ενεργειών")
("executive" "executive")
("exercise" "άσκηση")
("exit graphics" "γραφικά εξόδου")
("exit graphics mode" "λειτουργία εξόδου γραφικών")
("exit left" "έξοδος αριστερά")
("exit right" "έξοδος δεξιά")
("exit tag on the left" "έξοδος από την ετικέτα αριστερά")
("exit tag on the right" "έξοδος από την ετικέτα δεξιά")
("expand" "ανάπτυγμα")
("expand TeXmacs macros with no LaTeX equivalents" "ανάπτυξη μακροεντολών TeXmacs χωρίς ισοδύναμα LaTeX")
("expand beamer slides" "ανάπτυξη διαφανειών beamer")
("expand inclusions" "ανάπτυξη προσθηκών")
("expand logarithms" "ανάπτυγμα λογαρίθμων")
("expand trigonometric functions" "ανάπτυγμα τριγωνομετρικών συναρτήσεων")
("expand unrecognized macros" "ανάπτυγμα μη αναγνωρίσιμων μακροεντολών")
("expand user-defined macros" "ανάπτυγμα μακροεντολών ορισμένων από τον χρήστη")
("expanded" "αναπτυγμένη")
("experimental features (to be used with care)" "πειραματικά χαρακτηριστικά (για χρήση με προσοχή)")
("explain" "εξήγηση")
("explained" "περιγραφή ")
("explanatory item" "επεξηγηματικό στοιχείο")
("explicit keystroke" "ρητή πληκτρολόγηση")
("explicit margins" "ρητά περιθώρια")
("exponential" "εκθετική")
("exponential functions" "εκθετικές συναρτήσεις")
("export" "εξαγωγή")
("export as" "εξαγωγή ως")
("export bibliographies as links" "εξαγωγή βιβλιογραφιών ως σύνδεσμοι")
("export bibliography" "εξαγωγή βιβλιογραφίας")
("export entries in buffer" "εξαγωγή καταχωρήσεων στο buffer")
("export file" "εξαγωγή αρχείου")
("export formulas as images" "εξαγωγή τύπων σαν  εικόνες")
("export mathematical formulas as MathML" "εξαγωγή μαθηματικών τύπων ως MathML")
("export mathematical formulas as images" "εξαγωγή μαθηματικών τύπων ως εικόνων")
("export selected entries" "εξαγωγή επιλεγμένων καταχωρήσεων")
("export selection" "εξαγωγή επιλογής")
("export selection as image" "εξαγωγή επιλογής ως εικόνα")
("export selections as" "εξαγωγή επιλογών ως")
("export sessions" "εξαγωγή συνεδριάσεων")
("exported bibliographic entries" "εξαχθείσες βιβλιογραφικές καταχωρήσεις")
("exported bibliographic references" "εξαχθείσες βιβλιογραφικές αναφορές")
("extend" "επέκταση")
("extend or normal" "επέκταση ή κανονικό")
("extended" "εκτεταμένη")
("extensible left arrow" "επεκτάσιμο αριστερό βέλος")
("extensible right arrow" "επεκτάσιμο δεξιό βέλος")
("extern" "εξωτερικό")
("extern " "extern")
("external" "εξωτερικό")
("extra" "επιπλέον")
("extra branch" "επιπλέον κλάδος")
("extra interline space" "επιπλέον διάστημα μεταξύ γραμμών")
("extra name" "επιπλέον όνομα")
("extract" "απόσπαση")
("extract format" "εξαγωγή μορφής")
("extract style file" "εξαγωγή αρχείου στυλ")
("extract style package" "εξαγωγή πακέτου στυλ")
("factor" "παραγοντοποίηση")
("fade" "εξασθένηση")
("fade in" "βαθμιαία εμφάνιση")
("fade out" "βαθμιαία θόλωση")
("family" "οικογένεια")
("fast" "γρήγορα")
("fast decrease" "γρήγορη μείωση")
("fast environments" "γρήγορα περιβάλλοντα")
("fast increase" "γρήγορη αύξηση")
("february" "Φεβρουάριος")
("field reference" "πεδίο αναφοράς")
("fifth" "πέμπτο")
("figure" "σχήμα")
("file" "αρχείο")
("file name" "όνομα αρχείου")
("file not found" "το αρχείο δεν βρέθηκε")
("file saved" "αποθηκευμένο αρχείο")
("fill color" "χρώμα πλήρωσης")
("fill out" "συμπληρωση")
("filter" "φίλτρο")
("find file" "βρείτε αρχείο")
("find next match" "αναζήτηση επόμενου")
("find text" "αναζήτηση κειμένου")
("finished collecting symbols documentation" "ολοκληρώθηκε η συλλογή τεκμηρίωσης συμβόλων")
("finnish" "φινλανδικά")
("first" "πρώτο")
("first chunk" "πρώτο κομμάτι")
("first contact" "πρώτη επαφή")
("first difference" "πρώτη διαφορά")
("first error" "πρώτο σφάλμα")
("first field" "πρώτο πεδίο")
("first indentation" "πρώτη εσοχή")
("first item" "πρώτο αντικείμενο")
("first occurrence" "πρώτη εμφάνιση")
("first page" "πρώτη σελίδα")
("first similar" "πρώτο παρόμοιο")
("first start" "πρώτη εκκίνηση")
("fit to screen" "προσαρμογή στην οθόνη")
("fit to screen width" "προσαρμογή στο πλάτος της οθόνης")
("five columns" "πέντε στήλες")
("fixed" "σταθερή")
("flag is off" "η σημαία είναι απενεργοποιημένη")
("flag is on" "η σημαία είναι ενεργοποιημένη")
("flat" "επίπεδο")
("flatten" "ισοπεδώστε")
("flexibility" "προσαρμοστικότητα")
("flexibility factor for vertical spacing" "συντελεστής προσαρμοστικότητας για τα κάθετα περιθώρια")
("floating algorithm" "μετακινούμενος αλγόριθμος")
("floating figure" "μετακινούμενο σχήμα")
("floating object" "μετακινούμενο αντικείμενο")
("floating phantom" "αιωρούμενο φάντασμα")
("floating table" "μετακινούμενος πίνακας")
("focus" "εστίαση")
("focus dependent icons" "εικονίδια εξαρτώμενα από την εστίαση")
("fold" "αναδίπλωση")
("fold all" "σύμπτυξη όλων")
("fold all fields" "αναδίπλωση όλων των πεδίων")
("fold back" "αναδίπλωση προς τα πίσω")
("fold input field" "αναδίπλωση πεδίου εισόδου")
("folded" "διπλωμένη")
("follow external links" "ακολουθήστε τους εξωτερικούς συνδέσμους")
("follow inverse links" "ακολουθήστε τους αντίστροφους συνδέσμους")
("font" "γραμματοσειρά")
("font base size" "βασικό μέγεθος γραμματοσειράς")
("font dpi" "dpi γραμματοσειράς")
("font effects" "εφέ γραμματοσειράς")
("font family" "οικογένεια γραμματοσειράς")
("font name" "όνομα γραμματοσειράς")
("font selector" "Επιλογέας γραμματοσειρών")
("font series" "σειρά γραμματοσειράς")
("font shape" "σχήμα γραμματοσειράς")
("font size" "μέγεθος γραμματοσειράς")
("font type" "τύπος γραμματοσειράς")
("font variant" "παραλλαγή γραμματοσειράς")
("fonts" "γραμματοσειρές")
("footer" "υποσέλιδο")
("footnote" "υποσημείωση")
("for" "for")
("for each" "για το καθένα")
("force reloading of translations" "αναγκαστική επαναφόρτωση των μεταφράσεων")
("foreground" "προσκήνιο")
("foreign" "ξένες")
("format" "μορφή")
("formatted and structured output" "μορφοποιημένη και δομημένη έξοδος")
("formatted date" "μορφοποιημένη ημερομηνία")
("formatting" "μορφοποίηση")
("formula" "μαθηματικός τύπος")
("formula style" "στυλ μαθηματικού τύπου")
("forward" "προς τα εμπρός")
("forward replace" "αντικατάσταση προς τα εμπρός")
("forward search" "αναζήτηση προς τα εμπρός")
("four columns" "τέσσερις στήλες")
("four dots" "τέσσερις κουκκίδες")
("fourth" "τέταρτο")
("fraction" "κλάσμα")
("fraktur" "fraktur")
("framed" "πλαισιωμένο")
("framed input fields" "πλαισιωμένα πεδία εισόδου")
("french" "γαλλικά")
("from" "από")
("from center" "από το κέντρο")
("front matter" "εισαγωγικές σελίδες")
("full" "πλήρης")
("full author list" "πλήρης κατάλογος συγγραφέων")
("full manuals" "πλήρη εγχειρίδια χρήσης")
("full screen mode" "λειτουργία πλήρους οθόνης")
("function" "συνάρτηση")
("functional" "συναρτησιακή")
("further customization" "περαιτέρω προσαρμογή")
("future changes" "μελλοντικές αλλαγές")
("gNU TeXmacs comes without any form of legal warranty" "το gNU TeXmacs δεν καλύπτεται από κάποια νόμιμη εγγύηση")
("gNU TeXmacs falls under the GNU general public license" "το gNU TeXmacs υπόκειται στην GNU general public license")
("gap" "χάσμα")
("garbage collection" "συλλογή απορριμμάτων")
("gaussian" "Gaussian")
("gcd" "μκδ")
("general" "γενικά")
("general architecture of TeXmacs" "γενική αρχιτεκτονική του TeXmacs")
("general negation" "γενική άρνηση")
("general note" "γενική σημείωση")
("generated LaTeX document contains no errors" "το δημιουργημένο έγγραφο LaTeX δεν περιέχει σφάλματα")
("generated field" "το δημιουργημένο πεδίο")
("generating font file" "δημιουργία αρχείου γραμματοσειράς")
("generic" "γενικό")
("generic prompt color" "χρώμα προτροπής γενικής χρήσης")
("geometry" "γεωμετρία")
("georgian" "γεωργιανά")
("german" "γερμανικά")
("get arity" "λήψη arity")
("get label" "λήψη ετικέτας")
("get list with remote versions" "λήψη λίστας με απομακρυσμένες εκδόσεις")
("getting started" "τα πρώτα βήματα")
("glossary" "γλωσσάρι")
("glossary entry" "καταχώρηση γλωσσαρίου")
("glue" "επικόλληση")
("glue decorations" "επικόλληση διακοσμήσεων")
("glyphs" "γλύφοι")
("gnaw" "gnaw")
("gnawed" "gnawed")
("gnuPG command" "εντολή gnuPG")
("gnuPG error: buffer encryption failed" "σφάλμα gnuPG: αποτυχία κρυπτογράφησης buffer")
("gnuPG error: cannot find suitable secret key to decrypt" "σφάλμα gnuPG: δεν είναι δυνατή η εύρεση κατάλληλου μυστικού κλειδιού για την αποκρυπτογράφηση")
("gnuPG requires name and email to have at least 5 characters" "gnuPG απαιτεί όνομα και email να έχουν τουλάχιστον 5 χαρακτήρες")
("go" "μετάβαση")
("go to anchor" "μετάβαση στο anchor")
("go to anchor or float" "μετάβαση στο anchor ή στο αιωρούμενο")
("go to anchor or footnote" "μετάβαση στο anchor ή στην υποσημείωση")
("go to first similar tag" "μετάβαση στην πρώτη όμοια ετικέτα")
("go to float" "μετάβαση στο αιωρούμενο")
("go to footnote" "μετάβαση στην υποσημείωση")
("go to last similar tag" "μετάβαση στην τελευταία όμοια ετικέτα")
("go to next similar tag" "μετάβαση στην επόμενη όμοια ετικέτα")
("go to previous similar tag" "μετάβαση στην προηγούμενη όμοια ετικέτα")
("go to section" "μετάβαση στο κεφάλαιο")
("gothic" "γοτθικά")
("grain" "υφή")
("granite" "γρανίτη")
("graphical effects" "εφέ γραφικών")
("graphical interface" "γραφικό περιβάλλον")
("graphical interface font scale" "κλίμακα γραμματοσειράς γραφικής διεπαφής")
("graphics" "γραφικά")
("graphics geometry" "γεωμετρία γραφικών")
("graphics grids" "πλέγματα γραφικών")
("grave" "βαρεία")
("greater" "μεγαλύτερο")
("greater or equal" "μεγαλύτερο ή ίσο")
("greek" "ελληνικά")
("greek letter" "ελληνικό γράμμα")
("green" "πράσινο")
("grey" "γκρι")
("greyed" "γκριζα")
("grid" "Πλέγμα")
("grid curves" "καμπύλες πλέγματος")
("grid points" "σημεία πλέγματος")
("grid-curve intersections" "διατομές καμπύλης πλέγματος")
("group" "ομάδα")
("group of objects" "ομάδα αντικειμένων")
("group/ungroup" "ομαδοποίηση / αποομαδοποίηση")
("grouped" "ομαδοποιημένη")
("guarantee transparent source tracking" "εγγύηση διαφανούς παρακολούθησης πηγών")
("h modifier" "τροποποιητής h")
("half wide" "μισό πλάτος")
("hand drawn" "σχεδιασμένο με το χέρι")
("happy typing" "καλή πληκτρολόγηση")
("has been aborted" "έχει ματαιωθεί")
("has completed its task" "έχει ολοκληρώσει την εργασία του")
("hat" "καρρέ")
("header" "κεφαλίδα")
("header and footer" "κεφαλίδα και υποσέλιδο")
("headers" "κεφαλίδες")
("hebrew" "εβραϊκά")
("height" "ύψος")
("height is exactly the specified height" "το ύψος είναι ακριβώς το καθορισμένο")
("height is maximum of specified height and box height" "το ύψος είναι το μέγιστο από: το καθορισμένο και το ύψος πλαισίου")
("height is minimum of specified height and box height" "το ύψος είναι το ελάχιστο από: το καθορισμένο και το ύψος πλαισίου")
("height magnification" "αύξηση ύψους")
("help" "βοήθεια")
("help me" "βοηθήστε με")
("help us" "βοηθήστε μας")
("here" "εδώ")
("hidden" "κρυμμένο")
("history" "ιστορία")
("home" "αρχική")
("homepage" "αρχική σελίδα")
("homoglyph substitutions" "υποκαταστάσεις ομογλύφων")
("horizontal" "οριζόντια")
("horizontal alignment" "οριζόντια στοίχιση")
("horizontal cell alignment" "οριζόντια στοίχιση κελιού")
("horizontal collapse distance" "οριζόντια απόσταση κατάρρευσης")
("horizontal ink separation" "οριζόντιος διαχωρισμός γραφής")
("horizontal margins" "οριζόντια περιθώρια")
("horizontal part" "οριζόντιο τμήμα")
("horizontal position" "οριζόντια θέση")
("horizontal space" "οριζόντιος κενός χώρος")
("horizontal table alignment" "οριζόντια στοίχιση πίνακα")
("horizontally align cell to the base" "οριζόντια στοίχιση κελιού στη βάση")
("horizontally center the cell" "οριζόντιο κεντράρισμα κελιού")
("how much longer may pages become" "δυνατότητα επιμήκυνσης σελιδών")
("how much shorter may pages become" "δυνατότητα σμίκρυνσης σελιδών")
("huge" "τεράστιο")
("hungarian" "ουγγρικά")
("hybrid command" "υβριδική εντολή")
("hyperbolic functions" "υπερβολικές συναρτήσεις")
("hyperlink" "υπερσύνδεσμος")
("hyphenate as" "συλλαβισμός ως")
("hyphenation" "συλλαβισμός")
("icelandic" "ισλανδικά")
("icon" "εικονίδιο")
("if" "αν")
("if hyphenated" "αν συλλαβίζεται")
("ignore" "αγνοήστε")
("image" "εικόνα")
("image links" "σύνδεσμοι με εικόνα")
("impact" "επίδραση")
("implementation" "υλοποίηση")
("import" "εισαγωγή")
("import bibliography" "εισαγωγή βιβλιογραφίας")
("import database entry" "εισαγωγή καταχώρησης βάσης δεδομένων")
("import entries in buffer" "εισαγωγή καταχωρήσεων στο buffer")
("import entry" "εισαγωγή καταχώρησης")
("import file" "εισαγωγή αρχείου")
("import selected database entries" "εισαγωγή επιλεγμένων καταχωρήσεων βάσης δεδομένων")
("import selected entries" "εισαγωγή επιλεγμένων καταχωρήσεων")
("import selections as" "εισαγωγή επιλογών ως")
("import sessions" "εισαγωγή συνεδριών")
("import sophisticated objects as pictures" "εισαγωγή εξελιγμένων αντικειμένων ως εικόνες")
("imported bibliographic entries" "εισαγόμενες βιβλιογραφικές καταχωρήσεις")
("improving the current implementation" "βελτίωση της τρέχουσας υλοποίησης")
("in popup windows" "σε αναδυόμενα παράθυρα")
("inactive" "ανενεργό")
("inanimated" "μη κινούμενο")
("inbut border" "περίγραμμα εισόδου")
("inbut border color…" "χρώμα περιγράμματος εισόδου…")
("inch" "ίντσες")
("include" "συμπερίληψη")
("include a document" "συμπερίληψη εγγράφου")
("include file" "συμπερίληψη αρχείου")
("inclusion into TeXmacs" "συμπερίληψη στο TeXmacs")
("inclusions" "συμπεριλήψεις")
("incomplete entries found to be filled out" "ελλιπείς καταχωρίσεις που βρέθηκαν να συμπληρώνονται")
("increase size" "αύξηση μέγεθους")
("indent" "εσοχή")
("indent paragraphs" "εσοχή παραγράφου")
("indentation" "εσοχή")
("indentation flag" "σημαία εσοχής")
("index" "ευρετήριο")
("index entry" "καταχώρηση ευρετηρίου")
("index level" "επίπεδο ευρετηρίου")
("indication" "Ένδειξη")
("inflate" "διόγκωση")
("informative flags" "ενημερωτικές σημαίες")
("initialize" "αρχικοποίηση")
("ink here" "μελάνι εδώ")
("ink in" "μελάνι σε")
("ink out" "μελάνι έξω")
("inline" "ενσωματωμένο")
("inline arguments" "ενσωματωμένα ορίσματα")
("inline code" "ενσωματωμένος κώδικας")
("inline content" "ενσωματωμένο περιεχόμενο")
("inline formula" "ενσωματωμένος τύπος")
("inner bottom" "εσωτερικό κάτω μέρος")
("inner left" "εσωτερική αριστερά")
("inner right" "εσωτερική δεξιά")
("inner top" "εσωτερικό πάνω μέρος")
("input color" "χρώμα εισόδου")
("input command" "εντολή εισαγωγής")
("input field" "πεδίο εισαγωγής")
("input mode" "λειτουργία εισόδου")
("input options" "επιλογές εισόδου")
("insert" "εισαγωγή")
("insert Pr" "εισαγωγή Pr")
("insert a TeXmacs symbol" "εισαγωγή συμβόλου του TeXmacs")
("insert a big operator" "εισαγωγή μεγάλου τελεστή")
("insert a binary operation" "εισαγωγή δυαδικής πράξης")
("insert a binary relation" "εισαγωγή δυαδικής σχέσης")
("insert a blackboard bold character" "εισαγωγή χαρακτήρα σε blackboard bold")
("insert a bold calligraphic character" "εισαγωγή χαρακτήρα σε bold calligraphic")
("insert a bold character" "εισαγωγή χαρακτήρα σε bold")
("insert a calligraphic character" "εισαγωγή χαρακτήρα σε calligraphic")
("insert a computer program" "εισαγωγή προγράμματος υπολογιστή")
("insert a condition" "εισαγωγή συνθήκης")
("insert a control flow instruction" "εισαγωγή εντολής ελέγχου ροής")
("insert a fraction" "εισαγωγή κλάσματος")
("insert a fraktur character" "εισαγωγή χαρακτήρα σε fraktur")
("insert a gap" "εισάγετε κενό")
("insert a greek character" "εισαγωγή ελληνικού χαρακτήρα")
("insert a large left delimiter" "εισαγωγή μεγάλου αριστερού οριοθέτη")
("insert a large right delimiter" "εισαγωγή μεγάλου δεξιού οριοθέτη")
("insert a large separator" "εισαγωγή μεγάλου διαχωριστικού")
("insert a left subscript" "εισαγωγή αριστερού κάτω δείκτη")
("insert a link" "εισαγωγή συνδέσμου")
("insert a list" "εισαγωγή λίστας")
("insert a miscellaneous symbol" "εισαγωγή συμβόλου σε miscellaneous")
("insert a multiple choice" "εισαγωγή πολλαπλής επιλογής")
("insert a negation" "εισαγωγή άρνησης")
("insert a new branch" "εισαγωγή νέου κλάδου")
("insert a new entry" "εισαγωγή νέας καταχώρησης")
("insert a new item" "εισαγωγή νέου αντικειμένου")
("insert a note or a floating object" "εισαγωγή σημείωσης ή μετακινούμενου αντικειμένου")
("insert a numerical operation" "εισαγωγή αριθμητικής πράξης")
("insert a picture" "εισαγωγή φωτογραφίας")
("insert a prominent piece of text" "εισαγωγή εξέχοντος κειμένου")
("insert a question" "εισαγάγετε μια ερώτηση")
("insert a root" "εισαγωγή ρίζας")
("insert a script" "εισαγωγή δέσμης ενεργειών")
("insert a section block" "εισαγωγή αποσπάσματος κεφαλαίου")
("insert a square root" "εισαγωγή τετραγωνικής ρίζας")
("insert a table" "εισαγωγή πίνακα")
("insert a table or a matrix" "εισαγωγή πίνακα ή μαθηματικού πίνακα (μήτρας)")
("insert a textual operation" "εισαγωγή λειτουργίας κειμένου")
("insert a textual operator" "εισαγωγή τελεστή κειμένου")
("insert a wide symbol above" "εισαγωγή συμβόλου σε wide πάνω")
("insert a wide symbol below" "εισαγωγή συμβόλου σε wide κάτω")
("insert above" "εισαγωγή πάνω")
("insert abstract" "εισαγωγή περίληψης")
("insert an" "εισαγωγή")
("insert an accent" "εισαγωγή τόνου")
("insert an answer" "εισαγωγή απάντησης")
("insert an arrow" "εισαγωγή βέλους")
("insert an enunciation" "εισαγωγή διατύπωσης")
("insert an environment" "εισαγωγή περιβάλλοντος")
("insert an n" "εισαγωγή ν")
("insert an operation on tuples" "εισαγωγή πράξης σε πλειάδες")
("insert annotation" "εισαγωγή σχολιασμού")
("insert appendix" "εισαγωγή παραρτήματος")
("insert arccos" "εισαγωγή arccos")
("insert arcsin" "εισαγωγή arcsin")
("insert arctan" "εισαγωγή arctan")
("insert arg" "εισαγωγή arg")
("insert argument" "εισαγωγή ορίσματος")
("insert author" "εισαγωγή συγγραφέα")
("insert automatically generated content" "εισαγωγή αυτοματοποιημένου περιεχομένου")
("insert below" "εισαγωγή κάτω")
("insert big contour integral" "εισαγωγή μεγάλου επικαμπύλιου ολοκληρώματος")
("insert big coproduct" "εισαγωγή μεγάλου συγγινομένου")
("insert big direct sum" "εισαγωγή μεγάλου ευθέος αθροίσματος")
("insert big dotted point" "εισαγωγή μεγάλου διάστικτου κύκλου")
("insert big integral" "εισαγωγή μεγάλου ολοκληρώματος")
("insert big intersection" "εισαγωγή μεγάλης διχοτόμησης")
("insert big logical and" "εισαγωγή μεγάλου λογικού και")
("insert big logical or" "εισαγωγή μεγάλου λογικού ή")
("insert big product" "εισαγωγή μεγάλου γινομένου")
("insert big square union" "εισαγωγή μεγάλης τετραγωνικής ένωσης")
("insert big summation" "εισαγωγή μεγάλου αθροίσματος")
("insert big tensor product" "εισαγωγή μεγάλου τανυστικού γινομένου")
("insert big union" "εισαγωγή μεγάλης ένωσης")
("insert big union sum" "εισαγωγή μεγάλου αθροίσματος ενώσεων")
("insert big vertical space" "εισαγωγή μεγάλου κατακόρυφου κενού")
("insert chapter" "εισαγωγή κεφαλαίου")
("insert column" "εισαγωγή στήλης")
("insert column to the left" "εισαγωγή στήλης αριστερά")
("insert column to the right" "εισαγωγή στήλης δεξιά")
("insert copyright and license information" "εισαγωγή πληροφορίας πνευματικών δικαιωμάτων και άδειας χρήσης")
("insert cos" "εισαγωγή cos")
("insert cosh" "εισαγωγή cosh")
("insert cot" "εισαγωγή cot")
("insert coth" "εισαγωγή coth")
("insert csc" "εισαγωγή csc")
("insert deg" "εισαγωγή deg")
("insert det" "εισαγωγή det")
("insert dim" "εισαγωγή dim")
("insert dollar" "εισαγωγή συμβόλου δολλαρίου")
("insert equation" "εισαγωγή εξίσωσης")
("insert executable markup" "εισαγωγή εκτελέσιμης σήμανσης")
("insert exp" "εισαγωγή exp")
("insert explanatory item" "εισαγωγή επεξηγηματικού στοιχείου")
("insert field above" "εισαγωγή πεδίου πάνω")
("insert field below" "εισαγωγή πεδίου κάτω")
("insert fields" "εισαγωγή πεδίων")
("insert footnote" "εισαγωγή υποσημείωσης")
("insert formula" "εισαγωγή μαθηματικού τύπου")
("insert gcd" "εισαγωγή gcd")
("insert hom" "εισαγωγή hom")
("insert horizontal interword space" "εισαγωγή οριζόντιου κενού μεταξύ των λέξεων")
("insert image" "εισαγωγή εικόνας")
("insert inactive markup" "εισαγωγή ανενεργής σήμανσης")
("insert inf" "εισαγωγή inf")
("insert input field above" "εισαγωγή πεδίου εισόδου πάνω")
("insert input field below" "εισαγωγή πεδίου εισόδου κάτω")
("insert ker" "εισαγωγή ker")
("insert large delimiters" "εισαγωγή μεγάλων οριοθετών")
("insert last name" "εισαγωγή επωνύμου")
("insert left" "εισαγωγή αριστερά")
("insert lg" "εισαγωγή lg")
("insert lim" "εισαγωγή lim")
("insert liminf" "εισαγωγή liminf")
("insert limsup" "εισαγωγή limsup")
("insert ln" "εισαγωγή ln")
("insert log" "εισαγωγή log")
("insert macro" "εισαγωγή μακροεντολής")
("insert mathematics" "εισαγωγή μαθηματικών")
("insert max" "εισαγωγή max")
("insert medium horizontal space" "εισαγωγή οριζόντιου κενού μεσαίου μεγέθους")
("insert medium vertical space" "εισαγωγή κατακόρυφου κενού μεσαίου μεγέθους")
("insert min" "εισαγωγή ελαχίστου")
("insert missing invisible operators" "εισαγωγή αόρατων τελεστών που λείπουν")
("insert more names" "εισαγωγή περισσοτέρων ονομάτων")
("insert negative horizontal space" "εισαγωγή αρνητικού οριζόντιου κενού")
("insert new item or number" "εισαγωγή νέου στοιχείου ή αριθμού")
("insert new rows or columns" "εισαγωγή νέων σειρών ή στηλών")
("insert or delete rows or columns" "εισαγωγή ή διαγραφή σειρών ή στηλών")
("insert particle" "εισαγωγή σωματιδίου")
("insert plain text" "εισαγωγή απλού κειμένου")
("insert right" "εισαγωγή δεξιά")
("insert row" "εισαγωγή σειράς")
("insert row above" "εισαγωγή σειράς πάνω")
("insert row below" "εισαγωγή σειράς κάτω")
("insert sec" "εισαγωγή sec")
("insert section" "εισαγωγή ενότητας")
("insert sharp" "εισαγωγή δίεσης")
("insert similar above" "εισαγωγή παρόμοια πάνω")
("insert similar below" "εισάγωγή παρόμοια κάτω")
("insert similar block above" "εισαγωγή παρόμοιου αποσπάσματος πάνω")
("insert similar block below" "εισαγωγή παρόμοιου αποσπάσματος κάτω")
("insert sin" "εισαγωγή sin")
("insert sinh" "εισαγωγή sinh")
("insert small horizontal space" "εισαγωγή οριζόντιου κενού μικρού μεγέθους")
("insert small vertical space" "εισαγωγή κατακόρυφου κενού μικρού μεγέθους")
("insert structural markup" "εισαγωγή δομημένης σήμανσης")
("insert subsection" "εισαγωγή υποενότητας")
("insert subsubsection" "εισαγωγή υπό-υποενότητας")
("insert subtable" "εισαγωγή υποπίνακα")
("insert sup" "εισαγωγή sup")
("insert symbol documentation" "εισαγωγή τεκμηρίωσης συμβόλου")
("insert tan" "εισαγωγή tan")
("insert tanh" "εισαγωγή tanh")
("insert template" "εισαγωγή προτύπου")
("insert text field" "εισαγωγή πεδίου κειμένου")
("insert text field above" "εισαγωγή πεδίου κειμένου πάνω")
("insert text field below" "εισαγωγή πεδίου κειμένου κάτω")
("insert thick horizontal space" "εισαγωγή παχιού οριζόντιου κενού")
("insert title" "εισαγωγή τίτλου")
("insert title after name" "εισαγωγή τίτλου μετά το όνομα")
("insert user interface related markup" "εισαγωγή σήμανσης σχετικής με την διεπαφή χρήστη")
("insert value" "εισαγωγή τιμής")
("inserting control points" "εισαγωγή σημείων ελέγχου")
("integer arithmetic" "αριθμητική ακεραίων")
("integrate" "ολοκλήρωση")
("interactive command" "διαδραστική εντολή")
("interactive questions" "διαδραστικές ερωτήσεις")
("intercharacter compression" "συμπίεση μεταξύ χαρακτήρων")
("intercharacter stretching" "αποσυμπίεση μεταξύ των χαρακτήρων")
("interfacing" "διασύνδεση")
("interfacing TeXmacs with other systems" "διασύνδεση του TeXmacs με άλλα συστήματα")
("interjection" "παρεμβολή")
("interline separation" "διάστιχο")
("interline space" "απόσταση γραμμών")
("internationalization" "διεθνοποίηση")
("interparagraph space" "απόσταση παραγράφων")
("interrupt execution" "διακοπή εκτέλεσης")
("interrupted" "διακόπηκε")
("introduction" "εισαγωγή")
("invalid multi-paragraph selection" "λανθασμένη επιλογή πολλαπλών παραγράφων")
("invalid renaming" "λανθασμένη μετονομασία")
("inverse trigonometric rewriting" "αντίστροφη τριγωνομετρική επανεγγραφή")
("invert" "αντιστροφή")
("inverted breve" "ανεστραμμένο βραχύ σημείο (breve)")
("invisible" "αόρατο")
("invisible citation" "αόρατη παραπομπή")
("invisible ending" "αόρατο τέλος")
("invisible newline" "αόρατη νέα γραμμή")
("invisible opening" "αόρατο άνοιγμα")
("irish" "ιρλανδικά")
("is running" "εκτελείται")
("is tuple" "είναι πλειάδα")
("ispell does not respond" "το ispell δεν ανταποκρίνεται")
("ispell is already busy" "το ispell είναι απασχολημένο")
("italian" "ιταλικά")
("italic" "italic")
("italic right" "italic δεξιά")
("itemize" "σημειακή απαρίθμηση")
("january" "ιανουάριος")
("japanese" "ιαπωνικά")
("join selected cells" "ένωση επιλεγμένων κελιών")
("july" "ιούλιος")
("jump in" "μεταπήδηση")
("june" "ιούνιος")
("junior" "junior")
("justified" "πλήρως ευθυγραμισμένο")
("justify text" "πλήρης ευθυγράμμιση κειμένου")
("keep evaluated expressions" "διατήρηση αποτιμημένων παραστάσεων")
("keep local" "διατήρηση τοπικού")
("keep remote" "διατήρηση απομακρυσμένου")
("keep track of source code" "παρακολούθηση πηγαίου κώδικα")
("keep unfolded" "κρατήστε το ξεδιπλωμένο")
("key" "κλειδί")
("keyboard" "πληκτρολόγιο")
("keyboard configuration" "ρύθμιση πληκτρολογίου")
("keyboard equivalent" "συνδιασμός πλήκτρων")
("keyboard modifiers" "τροποποιητές πληκτρολογίου")
("keyboard shortcut" "συνδιασμός πλήκτρων")
("keymaps" "keymaps")
("keyword" "λέξη-κλειδί")
("keywords" "λέξεις-κλειδιά")
("kill" "εξουδετέρωση")
("known bugs" "γνωστά σφάλματα")
("label" "ετικέτα")
("landscape" "τοπίο")
("language" "γλώσσα")
("laptop presentation" "παρουσίαση με laptop")
("laptop presentations" "παρουσιάσεις από φορητό υπολογιστή")
("large" "μεγάλο")
("large cells" "μεγάλα κελιά")
("large closing bracket" "μεγάλη δεξιά αγκύλη")
("large delimiter" "μεγάλος οριοθέτης")
("large displayed" "μεγάλα εμφανιζόμενα")
("large displayed fraction" "μεγάλο εμφανιζόμενο κλάσμα")
("large opening bracket" "μεγάλη αριστερή αγκύλη")
("large separator" "μεγάλο διαχωριστικό")
("large tables" "μεγάλοι πίνακες")
("last" "τελευταίο")
("last difference" "τελευταία διαφορά")
("last error" "τελευταίο σφάλμα")
("last field" "τελευταίο πεδίο")
("last name" "επώνυμο")
("last occurrence" "τελευταία εμφάνιση")
("last page" "τελευταία σελίδα")
("last similar" "τελευταίο παρόμοιο")
("latex command" "εντολή latex")
("latin" "latin")
("layout" "διάταξη")
("lcm" "εκπ")
("left" "αριστερά")
("left aligned" "με αριστερή στοίχιση")
("left arrow" "αριστερό βέλος")
("left axis" "αριστερός άξονας")
("left baseline" "αριστερή γραμμή βάσης")
("left border" "αριστερό περίγραμμα")
("left bottom" "αριστερό κάτω μέρος")
("left cell border" "αριστερό περίγραμμα κελιού")
("left cell padding" "αριστερή αναπλήρωση κελιού")
("left center" "αριστερό κέντρο")
("left click: add point; Right click: undo" "αριστερό κλικ: επισύναψη σημείου, δεξί κλικ: αναίρεση")
("left click: finish; Right click: undo" "αριστερό κλικ: τερματισμός, δεξί κλικ: αναίρεση")
("left click: new object" "αριστερό κλικ: νέο αντικείμενο")
("left click: operate" "αριστερό κλικ: λειτουργία")
("left down" "αριστερά κάτω")
("left margin" "αριστερό περιθώριο")
("left on even pages" "αριστερά σε ζυγές σελίδες")
("left padding" "αναπλήρωση αριστερά")
("left prime" "left prime")
("left slanted" "κεκλιμένο αριστερά")
("left subscript" "αριστερός κάτω δείκτης")
("left superscript" "αριστερός πάνω δείκτης")
("left surrounding" "αριστερό περιβάλλον")
("left table border" "αριστερό περίγραμμα πίνακα")
("left table padding" "αριστερή αναπλήρωση πίνακα")
("left top" "αριστερό πάνω μέρος")
("left up" "αριστερά πάνω")
("left-right arrow" "αριστερό δεξί βέλος")
("leftwards" "προς τα αριστερά")
("legal" "legal")
("lemma" "λήμμα")
("length" "μήκος")
("less" "μικρότερο")
("less or equal" "μικρότερο ή ίσο")
("let the environment float" "αφήστε το περιβάλλον να αιωρείται")
("letter" "letter")
("license" "άδεια")
("light" "ανοιχτό")
("light grey" "ανοιχτό γκρι")
("limitations" "περιορισμοί")
("limits" "όρια")
("line" "γραμμή")
("line break" "αλλαγή γραμμής")
("line breaking" "Σπάσιμο γραμμής")
("line stretch" "επέκταση γραμμής")
("line wrapping" "αναδίπλωση γραμμής")
("linear 2D" "γραμμική 2D")
("linear algebra" "γραμμική άλγεβρα")
("lines around" "γραμμές γύρω-γύρω")
("link" "σύνδεσμος")
("link image" "σύνδεσμος με εικόνα")
("link image and copies as" "σύνδεση εικόνας και αντιγράφων ως")
("link image as" "σύνδεση εικόνας ως")
("link mode" "λειτουργία σύνδεσης")
("link to URL" "σύνδεση με την διεύθυνση URL")
("linking tool" "εργαλείο σύνδεσης")
("list" "λίστα")
("list of figures" "λίστα σχημάτων")
("list of tables" "λίστα πίνακων")
("live" "ζωντανά")
("live input-output" "ζωντανή είσοδος-έξοδος")
("load" "φόρτωση")
("load LaTeX file" "φόρτωση αρχείου LaTeX")
("load TeX file" "φόρτωση αρχείου TeX")
("load TeXmacs file" "φόρτωση αρχείου TeXmacs")
("load TeXmacs style file" "φόρτωση αρχείου στυλ TeXmacs")
("load a file" "φόρτωση αρχείου")
("load buffer" "φόρτωση προσωρινής αποθήκευσης")
("load file" "φόρτωση αρχείου")
("load help file" "φόρτωση αρχείου βοήθειας")
("load html file" "φόρτωση αρχείου html")
("load image" "φόρτωση εικόνας")
("load in new window" "φόρτωση σε νέο παράθυρο")
("load latex file" "φόρτωση αρχείου latex")
("load more recent autosave file" "φόρτωση του πιο πρόσφατα αυτοαποθηκευμένου αρχείου")
("load remote file" "φόρτωση απομακρυσμένου αρχείου")
("load tex file" "φόρτωση αρχείου tex")
("load verbatim file" "φόρτωση αρχείου verbatim")
("loaded" "φορτωμένο")
("loading" "φόρτωση")
("local entries" "τοπικές καταχωρήσεις")
("loci" "τόποι")
("locus" "τόπος")
("locus rendering" "απόδοση τόπου")
("logarithm" "λογάριθμος")
("logarithmic" "λογαριθμική")
("logarithmic base" "λογαριθμική βάση")
("logarithms" "λογάριθμοι")
("logging in" "σύνδεση")
("logical and" "λογικό και")
("logical implication" "λογική συνέπεια")
("logical not" "λογικό όχι")
("logical or" "λογικό ή")
("login" "σύνδεση")
("logout" "αποσύνδεση")
("long" "μακρύ")
("long macro" "μακρά μακροεντολή")
("long text" "μεγάλο κείμενο")
("look and feel" "look and feel")
("look for more fonts" "αναζήτηση περισσότερων γραμματοσειρών")
("look up" "αναζήτηση")
("loops" "βρόχοι")
("lower border" "κάτω περίγραμμα")
("m modifier" "τροποποιητής m")
("macro" "μακροεντολή")
("macro argument" "όρισμα μακροεντολής")
("macro definition" "ορισμός μακροεντολής")
("macro name" "όνομα μακροεντολής")
("macros" "μακροεντολές")
("magenta" "μωβ")
("magic" "μαγικό")
("magnification" "μεγένθυνση")
("magnified" "μεγενθυμένο")
("magnify horizontally" "μεγέθυνση οριζόντια")
("magnify vertically" "μεγέθυνση κάθετα")
("main" "κύριο")
("main document font" "κύρια γραμματοσειρά εγγράφου")
("main icon bar" "κύρια γραμμή εικονιδίων")
("main presentation style" "κύριο στυλ παρουσίασης")
("major changes" "σημαντικές αλλαγές")
("make a letter environment" "δημιουργία περιβάλλοντος γραμμάτων")
("make a multi-slide presentation" "δημιουργία παρουσίασης πολλαπλών διαφανειών")
("make a page insertion" "δημιουργία εισαγωγής σελίδας")
("make a subscript" "δημιουργία κάτω δείκτη")
("make a superscript" "δημιουργία πάνω δείκτη")
("make acute" "δημιουργία οξείας")
("make bar" "δημιουργία γραμμής")
("make check" "δημιουργία check")
("make floating" "δημιουργία αιωρούμενου")
("make fraction" "δημιουργία κλάσματος")
("make grave" "δημιουργία βαρείας")
("make hat" "δημιουργία καρρέ")
("make label" "δημιουργία ετικέτας")
("make link" "δημιουργία σύνδεσης")
("make negation" "δημιουργία άρνησης")
("make non floating" "δημιουργία μη αιωρούμενου")
("make page reference" "δημιουργία αναφοράς σε σελίδα")
("make reference" "δημιουργία αναφοράς")
("make square root" "δημιουργία τετραγωνικής ρίζας")
("make tilde" "δημιουργία περισπωμένης")
("make title" "δημιουργία τίτλου")
("make vector" "δημιουργία διανύσματος")
("making donations" "για δωρεές")
("manila paper" "χαρτί μανίλα")
("manual" "εγχειρίδιο χρήσης")
("map arguments" "απεικόνιση ορισμάτων")
("map to" "απεικόνιση στο")
("march" "μάρτιος")
("marginal note" "παρατήρηση")
("margins" "περιθώρια")
("margins as on paper" "περιθώρια όπως στο χαρτί")
("margins from width" "περιθώρια από πλάτος")
("margins on paper" "περιθώρια σε χαρτί")
("margins on screen" "περιθώρια στην οθόνη")
("marked" "με επισήμανση")
("master" "κύριο")
("master file" "κύριο αρχείο")
("material" "υλικό")
("math" "μαθηματικά")
("math font" "μαθηματική γραμματοσειρά")
("math font family" "οικογένεια μαθηματικής γραμματοσειράς")
("math font series" "σειρά μαθηματικής γραμματοσειράς")
("math font shape" "σχήμα μαθηματικής γραμματοσειράς")
("mathematical" "μαθηματικό")
("mathematical and customized input" "μαθηματική και προσαρμοσμένη είσοδος")
("mathematical font" "μαθηματική γραμματοσειρά")
("mathematical formulas" "μαθηματικοί τύποι")
("mathematical input" "μαθηματική είσοδος")
("mathematical output" "μαθηματικό εξαγόμενο")
("mathematical typesetting" "μαθηματική στοιχειοθεσία")
("mathematics" "μαθηματικά")
("matrices" "μαθηματικοί πίνακες (μήτρες)")
("matrix" "μαθηματικός πίνακας (μήτρα)")
("maximal" "μέγιστο")
("maximal cell height" "μέγιστο ύψος κελιού")
("maximal clustering" "μέγιστη συσσώρευση")
("maximal number of columns" "μέγιστος αριθμός στηλών")
("maximal number of rows" "μέγιστος αριθμός σειρών")
("maximal table height" "μέγιστο ύψος πίνακα")
("maximal table width" "μέγιστο πλάτος πίνακα")
("maximum" "μέγιστο")
("maximum mode" "μέγιστη λειτουργία")
("may" "μάιος")
("meander" "ελιγμός")
("medium" "μεσαίο")
("medium skip" "κενό μεσαίου μεγέθους")
("meminfo" "meminfo")
("memory" "μνήμη")
("memory usage" "χρήση μνήμης")
("menu" "μενού")
("merge" "συγχώνευση")
("merge lines into paragraphs unless separated by blank lines" "συγχώνευση γραμμών σε παραγράφους εκτός αν χωρίζονται με κενές γραμμές")
("messages" "μηνύματα")
("messy" "ακατάστατος")
("meta data" "μεταδεδομένα")
("meta key" "μετα-κλειδί")
("metadata" "μεταδεδομένα")
("metal" "μέταλλο")
("middle" "μεση")
("middle baseline" "μεσαία γραμμή αναφοράς")
("minimal" "ελάχιστο")
("minimal cell height" "ελάχιστο ύψος κελιού")
("minimal cell width" "ελάχιστο πλάτος κελιού")
("minimal line separation" "ελάχιστος διαχωρισμός γραμμών")
("minimal number of columns" "ελάχιστος αριθμός στηλών")
("minimal number of rows" "ελάχιστος αριθμός σειρών")
("minimal table height" "ελάχιστο ύψος πίνακα")
("minimal table width" "ελάχιστο πλάτος πίνακα")
("minimum" "ελάχιστο")
("minimum mode" "ελάχιστη λειτουργία")
("minus" "μείον")
("mirror" "αντικατοπτρισμός")
("miscellaneous" "διάφορα")
("miscellaneous features" "διάφορα χαρακτηριστικά")
("miscellanous" "διάφορα")
("mod" "mod")
("mode" "λειτουργία")
("mode dependent icons" "εικονίδια εξαρτώμενα από την λειτουργία")
("modifier" "τροποποιητής")
("modify cell alignment" "τροποποίηση στοίχισης κελιού")
("modify cell border" "τροποποίηση περιγράμματος κελιού")
("modify cell padding" "τροποποίηση αναπλήρωσης κελιού")
("modify cell size" "τροποποίηση μεγέθους κελιού")
("modify remote live document" "τροποποίηση απομακρυσμένου ενεργού εγγράφου")
("modify table border" "τροποποίηση περιγράμματος πίνακα")
("modify table padding" "τροποποίηση αναπλήρωσης πίνακα")
("module" "ενότητα")
("mongolian" "μογγολικά")
("monospaced" "μονοδιαστήματα")
("more information about GNU TeXmacs can be found in the Help" "περισσότερες πληροφορίες σχετικά με το GNU TeXmacs μπορείτε να βρείτε στη Βοήθεια")
("more information about GNU TeXmacs can be found in the Help->About menu" "περισσότερες πληροφορίες σχετικά με το GNU TeXmacs μπορείτε να βρείτε στο μενού Help-> About")
("more information about GNU TeXmacs can be found in the help" "περισσότερες πληροφορίες για το GNU TeXmacs στην βοήθεια")
("mosaic" "mosaic")
("motion" "κίνηση")
("mouse over object" "ποντίκι πάνω από αντικείμενο")
("move" "μετακίνηση")
("move down" "μετακίνηση κάτω")
("move object" "μετακίνηση αντικειμένου")
("move objects" "μετακίνηση αντικειμένων")
("move over object on which to operate" "μετακίνηση πάνω από το αντικείμενο πάνω στο οποίο θα ενεργήσει")
("move to the right when finished" "στο τέλος, μετακίνηση δεξιά")
("move up" "μετακίνηση πάνω")
("multiline" "πολλαπλών γραμμών")
("multiline input" "εισόδος πολλών γραμμών")
("multiple choice" "πολλαπλή επιλογή")
("multiple root" "πολλαπλή ρίζα")
("multiplication" "πολλαπλασιασμός")
("mutator tags" "ετικέτες μεταλλάκτη ")
("my documents" "τα έγγραφά μου")
("n-th" "νιοστή")
("n-th root" "νιοστή ρίζα")
("name" "όνομα")
("navigation options" "επιλογές πλοήγησης")
("negation" "άρνηση")
("never" "ποτέ")
("new" "νέο")
("new account" "νέος λογαριασμός")
("new bibliography dialogue" "νέος διάλογος βιβλιογραφίας")
("new buffer" "νέα προσωρινή αποθήκευση")
("new column" "νέα στήλη")
("new document" "νέο έγγραφο")
("new double page" "νέα διπλή σελίδα")
("new double page before" "νέα διπλή σελίδα πριν")
("new entry" "νέα καταχώρηση")
("new identity" "νέα ταυτότητα")
("new item" "νέο στοιχείο")
("new line" "νέα γραμμή")
("new locus" "νέος τόπος")
("new macro" "νέα μακροεντολή")
("new number" "νέος αριθμός")
("new page" "νέα σελίδα")
("new page before" "νέα σελίδα πριν")
("new paragraph" "νέα παράγραφος")
("new passphrase" "νέα φράση πρόσβασης")
("new remote directory" "νέος απομακρυσμένος κατάλογος")
("new remote file" "νέο απομακρυσμένο αρχείο")
("new roman" "new roman")
("new row" "νέα σειρά")
("new style fonts" "γραμματοσειρές νέου στυλ")
("new style page breaking" "σπάσιμο σελίδας νέου στυλ")
("new table" "νέος πίνακας")
("new version" "νέα έκδοση")
("new window" "νέο παράθυρο")
("newer version" "νεότερη έκδοση")
("next" "επόμενο")
("next chunk" "επόμενο κομμάτι")
("next difference" "επόμενη διαφορά")
("next error" "επόμενο σφάλμα")
("next field" "επόμενο πεδίο")
("next line" "επόμενη γραμμή")
("next occurrence" "επόμενη εμφάνιση")
("next screen" "επόμενη οθόνη")
("next similar" "επόμενο παρόμοιο")
("no changes need to be saved" "καμμία αλλαγή προς αποθήκευση")
("no clustering" "χωρίς συσσώρευση")
("no completions" "χωρίς αποπεράτωση")
("no dictionary for" "απουσία λεξικού για")
("no errors have been corrected" "δεν έχουν διορθωθεί σφάλματα")
("no first indentation" "χωρίς πρώτη εσοχή")
("no grid" "χωρίς πλέγμα")
("no indentation" "χωρίς εσοχή")
("no line break" "χωρίς αλλαγή γραμμής")
("no matches found" "δεν βρέθηκαν αντιστοιχίες")
("no matches found for" "δεν βρέθηκαν αντιστοιχίες για")
("no more matches for" "δεν βρέθηκαν περισσότερες αντιστοιχίες για")
("no more redo information available" "το ιστορικό επαναλήψεων εξαντλήθηκε")
("no more undo information available" "το ιστορικό αναιρέσεων εξαντλήθηκε")
("no name" "χωρίς όνομα")
("no new public key in document" "δεν υπάρχει νέο δημόσιο κλειδί στο έγγραφο")
("no page break" "χωρίς αλλαγή σελίδας")
("no page break after" "χωρίς αλλαγή σελίδας μετά")
("no page break before" "χωρίς αλλαγή σελίδας πριν")
("no page numbers" "χωρίς αριθμούς σελίδων")
("no parent" "κανένας γονέας")
("no selection" "καμία επιλογή")
("no spelling errors" "κανένα λάθος ορθογραφίας")
("no spelling errors found in text" "δεν βρέθηκαν ορθογραφικά λάθη στο κείμενο")
("no style" "χωρίς στυλ")
("none" "κανένα")
("normal" "κανονική μορφή")
("normal loci" "φυσιολογικοί τόποι")
("norwegian" "νορβηγικά")
("not" "όχι")
("not allowed to remove home directory" "δεν επιτρέπεται η κατάργηση του αρχικού καταλόγου")
("not connected to server" "δεν υπάρχει σύνδεση με διακομιστή")
("not equal" "μη ίσο")
("not found" "δεν βρέθηκε")
("not yet implemented" "δεν έχει / έχουν ακόμη εφαρμοστεί")
("notation" "σημειογραφία")
("note" "σημείωση")
("notebook" "σημειωματάριο")
("november" "νοέμβριος")
("number" "αριθμός")
("number equation" "αρίθμηση εξίσωσης")
("number of columns" "αριθμός στηλών")
("number of polar steps" "αριθμός πολικών βημάτων")
("number of subunit steps" "αριθμός βημάτων υπομονάδας")
("number theoretical functions" "συναρτήσεις θεωρίας αριθμών")
("numbered equation" "αριθμημένη εξίσωση")
("numbered equations" "αριθμημένες εξισώσεις")
("numbering" "αρίθμηση")
("numerator" "αριθμητής")
("numeric" "αριθμητικές πράξεις")
("numeric spreadsheet" "Αριθμητικό υπολογιστικό φύλλο")
("numerical analysis" "αριθμητική ανάλυση")
("objectives" "στόχοι")
("occurrences" "εμφανίσεις")
("october" "οκτώβριος")
("odd page" "μονή σελίδα")
("odd page footer" "υποσέλιδο σελίδας με περιττό αριθμό")
("odd page header" "κεφαλίδα σελίδας με περιττό αριθμό")
("odd page left margin" "αριστερό περιθώριο σελίδας με περιττό αριθμό")
("odd page margin" "περιθώριο σελίδας με περιττό αριθμό")
("odd page right margin" "δεξιό περιθώριο σελίδας με περιττό αριθμό")
("odd page shift" "μετατόπιση σελίδας με περιττό αριθμό")
("odd page text" "κείμενο σελίδας με περιττό αριθμό")
("odd pages" "μονές σελίδες")
("of fingerprint" "δακτυλικών αποτυπωμάτων")
("off" "μη ενεργό")
("ok" "ok")
("old english" "αρχαία αγγλικά")
("old slavonic" "αρχαία σλαβικά")
("old style" "παλιό στυλ")
("old version" "παλιά έκδοση")
("older version" "παλαιότερη έκδοση")
("on" "ενεργό")
("on cells" "στα κελιά")
("on columns" "στις στήλες")
("on entire table" "σε όλο τον πίνακα")
("on rows" "στις σειρές")
("on the footer" "στο υποσέλιδο")
("on your system and set it up from the \"Security\" tab" "στο σύστημά σας και ρύθμιση από την καρτέλα \"Security\"")
("one column" "μία στήλη")
("one error has been corrected" "διορθώθηκε ένα σφάλμα")
("one lower case letter, one non alpha-numeric symbol" "ένα μικρό γράμμα, ένα μη αλφαριθμητικό σύμβολο")
("one numeric character, one upper case letter" "ένας αριθμητικός χαρακτήρας, ένα κεφαλαίο γράμμα")
("one spelling error has been corrected" "ένα ορθογραφικό λάθος διορθώθηκε")
("online documentation" "ηλεκτρονική τεκμηρίωση")
("online help" "ηλεκτρονική βοήθεια")
("only convert changes when re-importing" "μετατροπή αλλαγών μόνο κατά την επανεισαγωγή")
("only convert changes with respect to imported version" "μετατροπή αλλαγών μόνο σε σχέση με την εισαγόμενη έκδοση")
("only convert changes with respect to tracked version" "μετατροπή αλλαγών μόνο σε σχέση με την έκδοση υπό παρακολούθηση")
("only implemented for complete subtrees" "εφαρμόζεται μόνο για πλήρη υπόδεντρα")
("only inline tags" "μόνο ενσωματωμένες ετικέτες")
("only keep folded" "διατήρηση μόνο ως διπλωμένο")
("only keep unfolded" "διατήρηση μόνο ως ξεδιπλωμένο")
("only show semantic focus" "εμφάνιση μόνο σημασιολογικής εστίασης")
("opacity" "αδιαφάνεια")
("open" "άνοιγμα")
("open a new buffer" "άνοιγμα νέας προσωρινής αποθήκευσης")
("open bibliography" "άνοιγμα βιβλιογραφίας")
("open identities" "άνοιγμα ταυτοτήτων")
("open in new window" "άνοιγμα σε νέο παράθυρο")
("open key manager" "άνοιγμα διαχειριστή κλειδιού")
("open licence agreement" "άνοιγμα άδειας χρήσης")
("open mailbox" "άνοιγμα γραμματοκιβώτιου")
("open module browser" "άνοιγμα προγράμματος περιήγησης ενότητας")
("open new window" "νέο παράθυρο")
("open symbol browser" "άνοιγμα προγράμματος περιήγησης συμβόλων")
("open tool in separate window" "άνοιγμα εργαλείου σε ξεχωριστό παράθυρο")
("opening" "άνοιγμα")
("operation mode" "τύπος λειτουργίας")
("operation on named selection" "λειτουργία επί επώνυμης επιλογής")
("operation on primary selection" "λειτουργία επί πρωτεύουσας επιλογής")
("operation on secondary selection" "λειτουργία επί δευτερεύουσας επιλογής")
("operation on ternary selection" "λειτουργία επί τριτεύουσας επιλογής")
("optical" "οπτικό")
("option" "επιλογή")
("options" "επιλογές")
("or" "ή")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ή δώστε την πλήρη διαδρομή στην εντολή \"gpg\" ή \"gpg2\"")
("orange" "πορτοκαλί")
("order" "σειρά")
("ordinary symbol" "σύνηθες σύμβολο")
("orientation" "προσανατολισμός")
("origin" "προέλευση")
("original welcome message" "αρχικό μήνυμα καλωσορίσματος")
("ornamented" "διακοσμημένο")
("other" "άλλο")
("other login" "άλλη σύνδεση")
("other package" "άλλο πακέτο")
("other pages" "άλλες σελίδες")
("other projects" "άλλα έργα")
("other style" "άλλο στυλ")
("outer bottom" "εξωτερικό κάτω μέρος")
("outer left" "εξωτερικό αριστερά")
("outer right" "εξωτερικό δεξιά")
("outer top" "εξωτερικό πάνω μέρος")
("outline" "περίγραμμα")
("outlined" "σκιαγραφημένο")
("outlined emboss" "σκιαγραφημένο ανάγλυφο")
("outlined engrave" "σκιαγραφημένο σκάλισμα")
("outlined roman" "roman με περίγραμμα")
("output options" "επιλογές εξόδου")
("oval" "οβάλ")
("over" "επί")
("overbrace" "αγκύλη έκτασης από πάνω")
("overlap" "αλληλοεπικάλυψη")
("overlay" "επικάλυψη")
("overlays" "επιστρώσεις")
("overline" "υπεργράμμιση")
("overlined" "υπεργραμμισμένο")
("overview of the scheme extension language" "επισκόπηση της γλώσσας επέκτασης scheme")
("padded" "γεμισμένο")
("padding" "αναπλήρωση")
("padding above" "αναπλήρωση πάνω")
("padding below" "αναπλήρωση κάτω")
("page" "σελίδα")
("page background" "φόντο σελίδας")
("page bottom margin" "κάτω περιθώριο σελίδας")
("page break" "αλλαγή σελίδας")
("page break after" "αλλαγή σελίδας μετά")
("page break before" "αλλαγή σελίδας πριν")
("page breaking algorithm" "αλγόριθμος σπασίματος σελίδας")
("page height" "ύψος σελίδας")
("page insertion" "εισαγωγή σελίδας")
("page layout" "διάταξη σελίδας")
("page number" "Αριθμός σελίδας")
("page number rendering" "απόδοση αρίθμησης σελίδων")
("page number text" "κειμένο αριθμού σελίδας")
("page numbering" "αρίθμηση των σελίδων")
("page reference" "αναφορά σε σελίδα")
("page rendering" "Απόδοση σελίδας")
("page right margin" "δεξί περιθώριο σελίδας")
("page setup" "ρύθμιση σελίδας ")
("page top margin" "πάνω περιθώριο σελίδας")
("page type" "τύπος σελίδας")
("page width" "πλάτος σελίδας")
("palette" "παλέτα")
("panorama" "πανόραμα")
("paper" "χαρτί")
("paper size" "μέγεθος χαρτιού")
("paper type" "τύπος χαρτιού")
("papyrus" "πάπυρος")
("paragraph" "παράγραφος")
("paragraph mode" "λειτουργία παραγράφου")
("paragraph width" "πλάτος παραγράφου")
("paragraphs" "παράγραφοι")
("parametric curve" "παραμετρική καμπύλη")
("parametric surface" "παραμετρική επιφάνεια")
("parenthesis" "παρένθεση")
("parenthesized" "σε παρενθέσεις")
("part" "μέρος")
("particle" "σωματίδιο")
("passphrase encryption" "κρυπτογράφηση κωδικού πρόσβασης")
("passphrase wallet facilities are not currently available" "οι υπηρεσίες φράσεων πρόσβασης πορτοφολιού δεν είναι επί του παρόντος διαθέσιμες")
("passphrases are expected to have at least: 8 characters" "φράσεις πρόσβασης αναμένεται να έχουν τουλάχιστον: 8 χαρακτήρες")
("passphrases mismatch" "αναντιστοιχία φρασεών πρόσβασης")
("past changes" "προηγούμενες αλλαγές")
("paste" "επικόλληση")
("paste from" "επικόλληση από")
("paste text" "επικόλληση κειμένου")
("pastel" "παστέλ")
("path" "διαδρομή ")
("pattern" "μορφή")
("pause" "παύση")
("pen width" "πλάτος στυλό")
("perform operations on cells" "εκτέλεση πράξεων στα κελιά")
("perform operations on columns" "εκτέλεση πράξεων στις στήλες")
("perform operations on entire table" "εκτέλεση πράξεων σε όλο τον πίνακα")
("perform operations on rows" "εκτέλεση πράξεων στις σειρές")
("permanent" "μόνιμο")
("permanent footer" "μόνιμο υποσέλιδο")
("permanent header" "μόνιμη κεφαλίδα")
("permanently add to dictionary" "μόνιμη προσθήκη στο λεξικό")
("permanently insert into dictionary" "μόνιμη εισαγωγή στο λεξικό")
("permissions" "δικαιώματα")
("person" "πρόσωπο")
("personal dictionary has been modified" "το προσωπικό σας λεξικό τροποποιήθηκε")
("phantasy" "phantasy")
("phantom" "φάντασμα")
("phantoms" "ανύπακτα αντικείμενα")
("philosophy" "φιλοσοφία")
("phoenician" "phoenician")
("phonetic" "phonetic")
("physics and astronomy class" "τάξη φυσικής και αστρονομίας")
("picture" "εικόνα")
("pine" "πεύκα")
("pink" "ροζ")
("plain" "απλή")
("plain block" "απλό μπλοκ")
("plain boxes" "απλά πλαίσια")
("plain circles" "απλοί κύκλοι")
("plain tabular" "απλός πίνακας δεδομένων")
("planned changes" "σχεδιασμένες αλλαγές")
("plans for the future" "σχέδια για το μέλλον")
("play" "αναπαραγωγή")
("play animation" "αναπαραγωγή κινούμενων σχεδίων")
("please" "παρακαλώ")
("please install GnuPG software from https://www.gnupg.org" "παρακαλούμε εγκαταστήστε το λογισμικό GnuPG από https://www.gnupg.org")
("please wait" "παρακαλώ περιμένετε")
("plot" "plot")
("plug-ins" "πρόσθετα")
("plugin" "plugin")
("plugins" "plugins")
("plural" "πληθυντικός")
("plus" "συν")
("point" "σημείο")
("polar" "πολικό")
("polish" "πολωνικά")
("polygon" "πολύγωνο")
("polynomial arithmetic" "αριθμητική πολυωνύμων")
("pop server settings" "ρυθμίσεις διακομιστή ποπ")
("porting TeXmacs to other platforms" "μεταφορά του TeXmacs σε άλλες πλατφόρμες")
("portrait" "πορτραίτο")
("portuguese" "πορτογαλικά")
("position" "θέση")
("position float" "τοποθέτηση μετακινούμενου")
("position floating object" "τοποθέτηση μετακινούμενου αντικειμένου")
("position of marginal note" "θέση περιθωριακής σημείωσης")
("position the table" "τοποθέτηση πίνακα")
("poster formats" "μορφές αφίσας")
("poster theme" "θέμα αφίσας")
("postfix" "postfix")
("postscript" "postscript")
("postscript image" "εικόνα postscript")
("pre-alpha release" "δοκιμαστική έκδοση pre-alpha")
("preamble" "προοίμιο")
("preamble mode" "λειτουργία προοιμίου")
("preferences" "προτιμήσεις")
("preferences for editing mathematical formulas" "προτιμήσεις για την επεξεργασία μαθηματικών τύπων")
("preferences for tag" "προτιμήσεις για την ετικέτα")
("prefix" "πρόθεμα")
("presentation" "παρουσίαση")
("presentation mode" "λειτουργία παρουσίασης")
("presentation tag" "εμφάνιση γραμματοσειράς")
("presentation tool" "εργαλείο παρουσίασης")
("preserve" "διατήρηση")
("preserve tags" "διατήρηση ετικετών")
("pretty tree output" "αποτέλεσμα όμορφου δέντρου")
("preview" "προεπισκόπηση")
("preview before printing" "προεπισκόπηση εκτύπωσης")
("preview command" "εντολή προεπισκόπησης")
("preview with ghostview" "προεπισκόπηση μέσω ghostview")
("previous" "προηγούμενο")
("previous difference" "προηγούμενη διαφορά")
("previous error" "προηγούμενο σφάλμα")
("previous field" "προηγούμενο πεδίο")
("previous occurrence" "προηγούμενη εμφάνιση")
("previous screen" "προηγούμενη οθόνη")
("previous similar" "προηγούμενο παρόμοιο")
("primary" "πρωτεύον")
("prime" "πρώτο")
("primitive or macro" "αρχέγονο ή μακροεντολή")
("print" "εκτύπωση")
("print all" "εκτύπωση όλων")
("print all to file" "εκτύπωση όλων σε αρχείο")
("print buffer" "εκτύπωση buffer")
("print buffer to file" "εκτύπωση buffer σε αρχείο")
("print page selection" "εκτύπωση επιλεγμένων σελίδων")
("print page selection to file" "εκτύπωση επιλεγμένων σελίδων σε αρχείο")
("print to file" "εκτύπωση σε αρχείο")
("print to postscript file" "εκτύπωση σε αρχείο postscript")
("printer" "εκτυπωτής")
("printer dpi" "ανάλυση εκτυπωτή σε dpi")
("printer setup" "εγκατάσταση εκτυπωτή")
("printing command" "εντολή εκτύπωσης")
("problem" "πρόβλημα")
("professional" "επαγγελματικό")
("prog" "prog")
("prog font" "γραμματοσειρά prog")
("prog font family" "οικογένεια γραμματοσειράς prog")
("prog font series" "σειρά γραμματοσειράς prog")
("prog font shape" "σχήμα γραμματοσειράς prog")
("program" "πρόγραμμα")
("program bracket matching" "πρόγραμμα αντιστοίχισης αγκύλων")
("program bracket selections" "πρόγραμμα επιλογής αγκύλων")
("program commands" "εντολές προγράμματος")
("program font" "γραμματοσειρά προγράμματος")
("program interface for buffer management" "διεπαφή προγράμματος για τη διαχείριση buffer")
("program mode" "λειτουργία προγράμματος")
("programming" "προγραμματισμός")
("programming routines for editing documents" "ρουτίνες προγραμματισμού για την επεξεργασία εγγράφων")
("progressive" "προοδευτικά")
("project" "έργο")
("projects" "έργα")
("prologue" "πρόλογος")
("prominent" "εξέχον")
("prompt on scripts" "προτροπή για την εκτέλεση scripts")
("prompts and default input" "προτροπές και προεπιλογή εισόδου")
("proof" "απόδειξη")
("proportional" "proportional")
("proportional typewriter" "proportional typewriter")
("proposition" "πρόταση")
("provoke C++ error" "πρόκληση σφάλματος C++")
("provoke menu error" "πρόκληση σφάλματος μενού")
("provoke scheme error" "πρόκληση σφάλματος scheme")
("pseudo code" "ψευτοκώδικας")
("public key encryption" "κρυπτογράφηση δημόσιου κλειδιού")
("public keys" "δημόσια κλειδιά")
("pulse" "παλμός")
("qt GUI only, sorry. Use \"Export selection\"" "συγγνώμη αλλά μόνο qt GUI. Χρήση επιλογής \"Εξαγωγή επιλογής\"")
("qt-widgets" "qt-widgets")
("quantifier" "ποσοτικοποιητής")
("quasi" "εν μέρει")
("query replace" "αναζήτηση και αντικατάσταση")
("question" "ερώτηση")
("questions only" "ερωτήσεις μόνο")
("questions with answers" "ερωτήσεις με απαντήσεις")
("quick evaluation of formulas" "γρήγορος υπολογισμός τύπων")
("quit" "έξοδος")
("quotation" "παράθεμα")
("quote" "παράθεση")
("range" "εύρος")
("rank" "βαθμός/τάξη")
("raw" "ακατέργαστο")
("real" "πραγματικοί")
("really close it" "επιβεβαίωση κλεισίματος")
("really delete user identity" "Διαγράψτε πραγματικά την ταυτότητα του χρήστη")
("really huge" "πραγματικά τεράστιο")
("really quit" "επιβεβαίωση τερματισμού")
("really tiny" "πολύ μικροσκοπικό")
("rebuild translations file" "επαναδημιουργία αρχείου μεταφράσεων")
("recent" "πρόσφατα")
("recent documents" "πρόσφατα έγγραφα")
("recipients" "παραλήπτες")
("recognize" "αναγνώριση")
("recover autosave file" "ανάκτηση αρχείου αυτόματης αποθήκευσης")
("rectangular" "ορθογώνιο")
("red" "κόκκινο")
("redo" "επανάληψη ενέργειας")
("redo undone changes" "επανάληψη μη γενόμενων αλλαγών")
("reduce" "reduce")
("reduce bottom margin by" "μείωση κάτω περιθωρίου κατά")
("reduce left margin by" "μείωση αριστερού περιθωρίου κατά")
("reduce margins" "μείωση περιθωρίων")
("reduce right margin by" "μείωση δεξιού περιθωρίου κατά")
("reduce top margin by" "μείωση πάνω περιθωρίου κατά")
("reduce trigonometric functions" "αναγωγή τριγωνομετρικών συναρτήσεων")
("reduced margins" "μειωμένα περιθώρια")
("reduction even page margin" "μείωση περιθωρίου άρτιων σελίδων")
("reduction odd page margin" "μείωση περιθωρίου περιττών σελίδων")
("reduction page bottom margin" "μείωση κάτω περιθωρίου σελίδας")
("reduction page right margin" "μείωση δεξιού περιθωρίου σελίδας")
("reduction page top margin" "μείωση πάνω περιθωρίου σελίδας")
("reference" "αναφορά")
("reference guide" "οδηγός αναφοράς")
("reference guide for the TeXmacs primitives" "οδηγός αναφοράς για τα αρχέτυπα του TeXmacs")
("reference guide for the standard TeXmacs styles" "οδηγός αναφοράς για τα βασικά στυλ του TeXmacs")
("references" "αναφορές")
("regenerate" "αναδημιουργία")
("register file" "εγγραφή αρχείου")
("regular" "κανονικό")
("relate" "συσχέτιση")
("relation" "σχέση")
("release" "έκδοση")
("release left button: finish editing" "απελευθέρωση αριστερού κουμπιού: τέλος επεξεργασίας")
("reload" "επαναφόρτωση")
("remark" "σχόλιο")
("remote" "απομακρυσμένη")
("remote connections" "απομακρυσμένες συνδέσεις")
("remote control" "τηλεχειρισμός")
("remote controllers with keyboard simulation" "τηλεχειριστήρια με προσομοίωση πληκτρολογίου")
("remote directory" "απομακρυσμένος κατάλογος")
("remote servers" "απομακρυσμένοι διακομιστές")
("remote tool" "απομακρυσμένο εργαλείο")
("remove" "κατάργηση")
("remove all output fields" "κατάργηση όλων των πεδίων εξόδου")
("remove banner" "κατάργηση αρχικού λογότυπου")
("remove database entry" "αφαίρεση καταχώρησης της βάσης δεδομένων")
("remove downwards" "αφαίρεση προς τα κάτω")
("remove entries" "αφαίρεση καταχωρήσεων")
("remove entry" "Αφαίρεση καταχώρησης")
("remove field above" "αφαίρεση πεδίου πάνω")
("remove field below" "Αφαίρεση πεδίου κάτω")
("remove fields" "κατάργηση πεδίων")
("remove folded" "αφαίρεση διπλωμένου")
("remove input field" "κατάργηση του πεδίου εισόδου")
("remove input field above" "κατάργηση του πεδίου εισόδου πάνω")
("remove last field" "κατάργηση τελευταίου πεδίου")
("remove leftwards" "αφαίρεση προς τα αριστερά")
("remove link" "αφαίρεση συνδέσμου")
("remove next field" "κατάργηση επόμενου πεδίου")
("remove number" "κατάργηση αριθμού")
("remove package" "κατάργηση πακέτου")
("remove previous field" "κατάργηση προηγούμενου πεδίου")
("remove rightwards" "αφαίρεση προς τα δεξιά")
("remove selected database entries" "αφαίρεση επιλεγμένων καταχωρήσεων βάσης δεδομένων")
("remove selected entries" "Αφαίρεση επιλεγμένων καταχωρήσεων")
("remove superfluous invisible operators" "αφαίρεση περιττών αοράτων τελεστών")
("remove tag" "αφαίρεση ετικέτας")
("remove this branch" "αφαίρεση αυτού του κλάδου")
("remove this switch" "κατάργηση αυτού του διακόπτη")
("remove unfolded" "αφαίρεση ξεδιπλωμένου")
("remove upwards" "αφαίρεση προς τα πάνω")
("removed entries from database" "καταργημένες καταχωρήσεις από τη βάση δεδομένων")
("removed entry from database" "καταργημένη καταχώρηση από τη βάση δεδομένων")
("rename" "μετονομασία")
("rename section" "μετονομασία κεφαλαίου")
("renumber this page" "επαναρίθμηση αυτής της σελίδας")
("repeat" "επανάληψη")
("repeat object" "επανάληψη αντικειμένου")
("replace" "αντικατάσταση")
("replace TeXmacs styles with no LaTeX equivalents" "αντικατάσταση των στυλ του TeXmacs από μη ισοδύναμα του LaTeX")
("replace all further occurrences" "αντικατάσταση όλων των επόμενων")
("replace by" "αντικατάσταση από")
("replace one occurrence" "μόνο μία αντικατάσταση")
("replace toolbar" "αντικατάσταση γραμμής εργαλείων")
("replace unrecognized styles" "αντικατάσταση μη αναγνωρίσιμων στυλ")
("replaced" "αντικαταστάθηκε")
("replaced one occurrence" "αντικαταστάθηκε μια εμφάνιση")
("reset" "επαναφορά")
("reset error counters" "μετρητές σφαλμάτων επαναφοράς")
("resize" "αλλαγή μεγέθους")
("resize object" "αναπροσδιορισμός μεγέθους αντικειμένου")
("resize objects" "αλλαγή μεγέθους αντικειμένων")
("resized" "αναπροσδιορίστηκε το μέγεθος")
("restart TeXmacs in order to let changes take effect" "επανεκκίνηση του TeXmacs για να τεθούν σε ισχύ ο αλλαγές")
("restart in order to let the new look and feel take effect" "επανεκκίνηση για να τεθούν σε ισχύ η νέα εμφάνιση και αίσθηση")
("retain" "διατήρηση")
("retime" "επαναχρονομέτρηση")
("retina settings" "ρυθμίσεις οθόνης retina")
("retrieve email" "Ανάκτηση email")
("retrieve remote live document" "ανάκτηση απομακρυσμένου ενεργού εγγράφου")
("retrieved contents" "ανακτημένα περιεχόμενα")
("return" "επιστροφή")
("reverse" "αντίστροφη")
("reverse ordering" "αντίστροφη διάταξη")
("revert" "επαναφορά")
("revert buffer" "επαναφορά προσωρινής αποθήκευσης")
("rewriting" "επανεγγραφή")
("ridged paper" "χαρτί με ραβδώσεις")
("right" "δεξιά")
("right aligned" "με δεξιά στοίχιση")
("right arrow" "δεξιό βέλος")
("right baseline" "δεξιά γραμμή βάσης")
("right border" "δεξί περίγραμμα")
("right cell border" "δεξί περίγραμμα κελιού")
("right cell padding" "δεξιά αναπλήρωση κελιού")
("right down" "δεξιά κάτω")
("right margin" "δεξί περιθώριο")
("right on even pages" "δεξιά σε ζυγές σελίδες")
("right padding" "αναπλήρωση δεξιά")
("right subscript" "δεξιός κάτω δείκτης")
("right superscript" "δεξιός πάνω δείκτης")
("right surrounding" "δεξί περιβάλλον")
("right table border" "δεξί περίγραμμα πίνακα")
("right table padding" "δεξιά αναπλήρωση πίνακα")
("right up" "δεξιά επάνω")
("rightwards" "προς τα δεξιά")
("rigid" "άκαμπτο")
("rigid box" "άκαμπτο πλαίσιο")
("rigid horizontal" "άκαμπτο οριζόντια")
("rigid space" "άκαμπτο κενό")
("ring binder notebook style" "στυλ σημειωματαρίου με συνδετικούς κρίκους")
("romanian" "ρουμανικά")
("root" "ρίζα")
("rotate" "περιστροφή")
("rotate backward" "περιστροφή προς τα πίσω")
("rotate forward" "περιστροφή προς τα εμπρός")
("rotate objects" "περιστροφή αντικειμένων")
("rough" "τραχύ")
("rough paper" "ακατέργαστο χαρτί")
("round" "κυκλικό")
("round overbrace" "κυκλική πάνω αγκύλη")
("round underbrace" "κυκλική κάτω αγκύλη")
("row" "σειρά")
("row above" "σειρά πάνω")
("row below" "σειρά κάτω")
("row contains glued items" "η σειρά περιέχει επικόλλημένα αντικείμενα")
("rows" "σειρές")
("run" "εκτέλεση")
("run current file" "εκτέλεση τρέχοντος αρχείου")
("runic" "ρουνικά")
("running author" "τρέχων συγγραφέας")
("running title" "τρέχων τίτλος")
("russian" "ρωσικά")
("same names" "ίδια ονόματα")
("same screen margins as on paper" "ίδια περιθώρια οθόνης όπως στο χαρτί")
("sample" "δείγμα")
("sample text" "δείγμα κειμένου")
("sans serif" "sans serif")
("save" "αποθήκευση")
("save TeXmacs file" "αποθήκευση αρχείου TeXmacs")
("save TeXmacs style file" "αποθήκευση αρχείου στυλ TeXmacs")
("save as" "αποθήκευση ως")
("save as LaTeX" "αποθήκευση ως LaTeX")
("save as TeX" "αποθήκευση ως TeX")
("save auxiliary data" "αποθήκευση βοηθητικών δεδομένων")
("save buffer" "αποθήκευση προσωρινής αποθήκευσης")
("save buffer as" "αποθήκευση προσωρινής αποθήκευσης ως")
("save entries" "αποθήκευση καταχωρήσεων")
("save entry" "αποθήκευση καταχώρησης")
("save file" "αποθήκευση αρχείου")
("save html file" "αποθήκευση αρχείου html")
("save image" "αποθήκευση εικόνας")
("save image as" "αποθήκευση εικόνας ως")
("save latex file" "αποθήκευση αρχείου latex")
("save position" "αποθήκευση θέσης")
("save remote file" "Αποθήκευση απομακρυσμένου αρχείου")
("save tex file" "αποθήκευση αρχείου tex")
("save this buffer" "αποθήκευση αυτής της προσωρινής αποθήκευσης")
("save verbatim file" "αποθήκευση αρχείου verbatim")
("saved" "αποθηκεύτηκε")
("saved modifications in database" "αποθηκευμένες τροποποιήσεις στη βάση δεδομένων")
("scheme command" "εντολή scheme")
("scheme developers guide" "οδηγός προγραμματιστών scheme")
("scheme extensions" "επεκτάσεις scheme")
("scheme interface for the graphical mode" "Διεπαφή scheme για τη γραφική λειτουργία")
("screen" "Οθόνη")
("screen layout" "διάταξη οθόνης")
("screen margins" "περιθώρια οθόνης")
("screen rendering" "απόδοση οθόνης")
("screens" "Οθόνες")
("screenshot" "στιγμιότυπο οθόνης")
("script" "script")
("script above" "script πάνω")
("script below" "script κάτω")
("script script size" "μέγεθος script script")
("script size" "μέγεθος script")
("scripting language" "γλώσσα δέσμης ενεργειών")
("scripts" "δέσμες ενεργειών")
("scripts not accepted" "μη αποδοχή scripts")
("search" "αναζήτηση")
("search and replace" "αναζήτηση και αντικατάσταση")
("search results for" "αποτελέσματα αναζήτησης για")
("search toolbar" "αναζήτηση γραμμής εργαλείων")
("search words in my documents" "αναζήτηση λέξεων στα έγγραφά μου")
("search words in the documentation" "αναζήτηση λέξεων στην τεκμηρίωση")
("search words in the source code" "αναζήτηση λέξεων στον πηγαίο κώδικα")
("searching" "αναζήτηση…")
("second" "δεύτερη")
("secondary" "δευτερεύον")
("secret keys" "μυστικά κλειδιά")
("section" "ενότητα")
("sections" "κεφάλαια")
("security" "ασφάλεια")
("see" "βλέπε")
("see documentation" "βλέπε τεκμηρίωση")
("select a document style" "επιλογή στυλ εγγράφου")
("select a foreground color" "επιλογή χρώματος προσκηνίου")
("select a language" "επιλογή γλώσσας")
("select pen" "επιλογή στυλό")
("select the action to be undertaken for each conflict" "επιλογή  ενέργειας που πρέπει να αναληφθεί για κάθε αντίθεση")
("select view mode" "επιλογή λειτουργίας προβολής")
("selected region" "επιλεγμένη περιοχή")
("selection" "επιλογή")
("selections" "επιλογές")
("semantic correctness" "σημασιολογική ορθότητα")
("semantic editing" "σημασιολογική επεξεργασία")
("semantic selections" "σημασιολογικές επιλογές")
("semantics" "σημασιολογία")
("seminar" "σεμινάριο")
("sending commands to TeXmacs" "αποστολή εντολών στο TeXmacs")
("senior" "ανώτερος")
("separation between lines" "διαχωρισμός γραμμών")
("separation between paragraphs" "διαχωρισμός παραγράφων")
("separator" "διαχωριστικό")
("september" "Σεπτέμβριος")
("serb" "σερβικά")
("series" "σειρά")
("series|right" "σειρά|δεξιά")
("serif" "serif")
("server" "διακομηστής")
("session" "συνεδρία")
("session commands" "εντολές συνεδρίας")
("session left indent" "αριστερή εσοχή συνεδρίας")
("session name" "όνομα συνεδρίας")
("session right indent" "δεξιά εσοχή συνεδρίας")
("session ring width" "μέγεθος  κρίκων της συνεδρίας")
("session type" "τύπος συνεδρίας")
("sessions" "συνεδρίες")
("set" "ρύθμιση")
("set background color of cell" "ρύθμιση χρώματος παρασκηνίου κελιού")
("set cell mode" "ρύθμιση λειτουργίας κελιού")
("set default" "ορισμός προεπιλογής")
("set difference" "ορισμός διαφοράς")
("set extension center" "ρύθμιση του κέντρου επέκτασης")
("set height" "ρύθμιση ύψους")
("set height of cell" "ρύθμιση ύψους κελιού")
("set intersection" "διασταυρώσεις")
("set margins" "ρύθμιση περιθωρίων")
("set n" "ρύθμιση τιμής του ν")
("set number of columns" "ορισμός αριθμού στηλών")
("set number of rows" "ορισμός αριθμού γραμμών")
("set or get environment variables" "ρύθμιση ή λήψη μεταβλητών περιβάλλοντος")
("set paragraph margins" "ρύθμιση περιθωρίων παραγράφου")
("set paragraph mode" "ρύθμιση λειτουργίας παραγράφου")
("set printer dpi" "ρύθμιση dpi εκτυπωτή")
("set printing command" "ρύθμιση εντολής εκτύπωσης")
("set properties" "ορισμός ιδιοτήτων")
("set span" "ρύθμιση ανοίγματος")
("set special cell properties" "ρύθμιση ειδικών ιδιοτήτων κελιού")
("set special table properties" "ρύθμιση ειδικών ιδιοτήτων πίνακα")
("set text width" "ρύθμιση πλάτους κειμένου")
("set union" "σύνολο ένωση")
("set user information" "ορισμός πληροφοριών χρήστη")
("set width" "ρύθμιση πλάτους")
("set width of cell" "ρύθμιση πλάτους κελιού")
("settings" "ρυθμίσεις")
("setup printer" "ρύθμιση εκτυπωτή")
("seventh" "έβδομο")
("several equations" "διάφορες εξισώσεις")
("shadow" "σκιά")
("shadowed" "σκιασμένη")
("shadowed raise" "σκιασμένη αύξηση")
("shape" "σχήμα")
("shift" "shift")
("shift-down" "shift-down")
("shift-right" "shift-right")
("short" "σύντομο")
("show" "προβολή")
("show all parts" "προβολή όλων των μερών")
("show current focus" "εμφάνιση τρέχουσας εστίασης")
("show full context" "εμφάνιση πλήρους περιβάλλοντος")
("show header and footer" "προβολή κεφαλίδας και υποσέλιδου")
("show hidden" "προβολή κρυμμένων")
("show key presses" "εμφάνιση πατήματος πλήκτρων")
("show main document" "εμφάνιση κύριου εγγράφου")
("show memory usage" "εμφάνιση χρήσης μνήμης")
("show on screen" "προβολή στην οθόνη")
("show one part" "προβολή ενός μέρους")
("show panorama" "πανοραμική εικόνα")
("show preamble" "εμφάνιση προοιμίου")
("show several parts" "προβολή  διαφόρων μερών")
("show subunits" "εμφάνιση υπομονάδων")
("show table cells" "εμφάνιση κελιών πίνακα")
("show timings" "προβολή χρόνου εκτέλεσης")
("shrinking factor" "παράγοντας σμίκρυνσης")
("side tools" "πλευρικά εργαλεία")
("signature" "υπογραφή")
("simple" "απλά")
("simplification" "απλοποίηση")
("simplified evaluation of formulas" "απλοποιημένη αποτίμηση των τύπων")
("simplified menus" "απλουστευμένα μενού")
("simplify" "απλοποίηση")
("sine" "ημίτονο")
("sixth" "έκτο")
("size" "μέγεθος")
("size limits" "όρια μεγέθους")
("size tag" "μεγέθος γραμματοσειράς")
("skew" "λοξά")
("skip all" "παράλειψη όλων")
("slant" "κλίση")
("slanted" "κεκλιμένο")
("slashed fraction" "κλάσμα με κάθετη γραμμή")
("slides" "διαφάνειες")
("sloppy" "ατημέλητα")
("slovene" "σλοβενικά")
("slow" "αργή")
("slow decrease" "αργή μείωση")
("slow increase" "αργή αύξηση")
("small" "μικρό")
("small capitals" "μικρά κεφάλαια")
("small caps" "καπιταλάκια")
("small environment box" "μικρό πλαίσιο περιβάλλοντος")
("small figure" "μικρό σχήμα")
("small focus" "μικρή εστίαση")
("small inline" "μικρό ενσωματωμένο")
("small inline fraction" "μικρό ενσωματωμένο κλάσμα")
("small skip" "μικρό κενό")
("small table" "μικρός πίνακας")
("smash" "συντριβή")
("smooth" "ομαλή")
("smooth end" "ομαλό άκρο")
("smooth extremities" "ομαλά άκρα")
("smooth start" "ομαλή εκκίνηση")
("snap" "κούμπωμα")
("snap distance" "απόσταση αποκοπής")
("snap to curves" "κούμπωμα στις καμπύλες")
("snap to grid" "κούμπωμα στο πλέγμα")
("snap to grid curve" "κούμπωμα στην καμπύλη του πλέγματος")
("snap to intersections of curves" "κούμπωμα στις διασταυρώσεις των καμπυλών")
("snap to text borders" "κούμπωμα στα όρια κειμένου")
("snap to text corners" "κούμπωμα στις γωνίες κειμένου")
("solution" "λύση")
("solution to exercise" "λύση για την άσκηση")
("solution to problem" "λύση στο πρόβλημα")
("solutions" "λύσεις")
("solving equations" "επίλυση εξισώσεων")
("sound" "ήχος")
("source" "πηγαίο")
("source code" "πηγαίος κώδικας")
("source macros tool" "Εργαλείο πηγαίου κώδικα μακροεντολών")
("source tags" "πηγαίες ετικέτες")
("south" "νότια")
("south east" "νοτιοανατολικά")
("space" "διάστημα")
("space bar in math mode" "πλήκτρο διαστήματος σε λειτουργία μαθηματικών")
("space bar in text mode" "πλήκτρο διαστήματος σε λειτουργία κειμένου")
("space between lines" "διάστημα μεταξύ γραμμών")
("space between paragraphs" "διάστημα μεταξύ παραγράφων")
("space stretchability" "ελαστικότητα αποστάσεων")
("spacing" "διάστημα")
("span" "επέκταση")
("span over all columns" "επέκταση πάνω από όλες τις στήλες")
("spanish" "ισπανικά")
("special" "ειδικό")
("special cell properties" "ειδικές ιδιότητες κελιού")
("special functions" "ειδικές συναρτήσεις")
("special properties" "ειδικές ιδιότητες")
("special table properties" "ειδικές ιδιότητες πίνακα")
("specific" "συγκεκριμένο")
("specific baseline" "ειδική γραμμή βάσης")
("specify color alternation" "καθορισμός εναλλαγής χρωμάτων")
("specify how to traverse the manual" "καθορισμός τρόπου περιφοράς στο εγχειρίδιο")
("specify semantics of a symbol or formula" "καθορισμός σημασιολογίας συμβόλου ή τύπου")
("specify the size of the table" "καθορισμός του μεγέθους πίνακα")
("spell" "ορθογραφία")
("spell check" "Έλεγχος ορθογραφίας")
("spell checking complete" "ο ορθογραφικός έλεγχος ολοκληρώθηκε")
("spelling error" "ορθογραφικό λάθος")
("spelling errors have been corrected" "τα ορθογραφικά λάθη διορθώθηκαν")
("spline" "καμπύλη spline")
("split" "διαίρεση")
("split program" "split program")
("split session" "διαίρεση συνεδρίας")
("square" "τετράγωνο")
("square overbrace" "τετράγωνη πάνω αγκύλη")
("square root" "τετραγωνική ρίζα")
("square underbrace" "τετράγωνη κάτω αγκύλη")
("stack" "στοίβα")
("standard" "τυπικό")
("standard Output" "τυπικό εξαγόμενο")
("standard TeXmacs styles" "τυπικά στυλ του TeXmacs")
("standard environment variables" "μεταβλητές τυπικού περιβάλλοντος")
("standard formats" "τυπικές μορφές")
("standard fraction" "τυπικό κλάσμα")
("star" "αστέρι")
("start" "έναρξη")
("start a new chapter" "έναρξη νέου κεφαλαίου")
("start a new section" "έναρξη νέας ενότητας")
("start an interactive session" "έναρξη συνεδρίας αλληλεπίδρασης")
("start server" "έναρξη διακομιστή")
("statement" "δήλωση")
("statistics" "στατιστικά")
("status" "Κατάσταση")
("status bar" "γραμμή κατάστασης")
("stop server" "παύση διακομιστή")
("storage" "αποθηκευτικός χώρος")
("store tracking information in LaTeX files" "αποθήκευση πληροφοριών παρακολούθησης σε αρχεία LaTeX")
("stretch" "τάνυσμα")
("stretch factor" "συντελεστής τάνυσης")
("stretchable" "τανυόμενο")
("stretchable horizontal" "τανυόμενο οριζόντια")
("stretchable vertical" "τανυόμενο κατακόρυφα")
("stretched" "τεντωμένο")
("strict Ascii" "αυστηρά Ascii")
("strike through" "μεσογραμμισμένο")
("stroke" "μολυβιά")
("strokes" "μολυβιές")
("strong" "strong")
("structural" "structural")
("structured insert above" "δομημένη εισαγωγή πάνω")
("structured insert at the left" "δομημένη εισαγωγή στα αριστερά")
("structured insert at the right" "δομημένη εισαγωγή στα δεξιά")
("structured insert below" "δομημένη εισαγωγή κάτω")
("structured remove downwards" "δομημένη αφαίρεση προς τα κάτω")
("structured remove leftwards" "δομημένη αφαίρεση προς τα αριστερά")
("structured remove rightwards" "δομημένη αφαίρεση προς τα δεξιά")
("structured remove upwards" "δομημένη αφαίρεση προς τα πάνω")
("structured variant" "δομημένη παραλλαγή")
("style" "στυλ")
("style options" "επιλογές στυλ")
("style parameters" "παράμετροι του στυλ")
("styles" "στυλ")
("stylesheet language" "γλώσσα stylesheet")
("sub" "υπό")
("subject" "θέμα")
("submenu" "υπομενού")
("subparagraph" "υποπαράγραφος")
("subscript" "κάτω δείκτης")
("subscript below" "δείκτης κάτω")
("subsection" "υποενότητα")
("subsub" "υπό-υπό")
("subsubmenu" "υπουπομενού")
("subsubsection" "υπό-υποενότητα")
("subsubsubmenu" "υπουπουπομενού")
("subsubsubsubmenu" "υπουπουπουπομενού")
("subtable" "υποπίνακας")
("subtitle" "υπότιτλος")
("subtraction" "αφαίρεση")
("summarized" "συνοψισμένη")
("summary" "περίληψη")
("summary of the principal TeXmacs tags" "περίληψη των κύριων ετικέτων στο TeXmacs")
("superpose" "υπέρθεση")
("superposed" "υπερτεθειμένο")
("superscript" "πάνω δείκτης")
("superscript above" "εκθέτης πάνω")
("supported plug-ins" "υποστηριζόμενα πρόσθετα")
("surface" "επιφάνεια")
("swedish" "σουηδικά")
("swiss" "ελβετικά")
("switch" "εναλλαγή")
("switch to buffer" "αλλαγή στο buffer")
("switch to first" "εναλλαγή στο πρώτο")
("switch to formula style" "εναλλαγή σε στυλ μαθηματικού τύπου")
("switch to last" "εναλλαγή στο τελευταίο")
("switch to next" "εναλλαγή στο επόμενο")
("switch to previous" "εναλλαγή στο προηγούμενο")
("switching and folding" "εναλλαγή και δίπλωση")
("symbol" "σύμβολο")
("symbol properties not found" "Δεν βρέθηκαν ιδιότητες συμβόλων")
("symbols" "σύμβολα")
("synchronize" "συγχρονισμός")
("synchronize bibliographic references" "συγχρονισμός βιβλιογραφικών αναφορών")
("synchronize with remote server" "συγχρονισμός με απομακρυσμένο διακομιστή")
("synopsis" "σύνοψη")
("system command" "εντολή του συστήματος")
("system environment variables" "μεταβλητές περιβάλλοντος του συστήματος")
("tab" "στηλοθέτηση")
("tab-completion" "συμπλήρωση εντολών")
("tabbed" "στηλοθετημένο")
("table" "πίνακας")
("table breaking" "σπάσιμο πίνακα")
("table command" "εντολή πίνακα")
("table height" "ύψος πίνακα")
("table of contents" "πίνακας περιεχομένων")
("table properties" "ιδιότητες πίνακα")
("table width" "πλάτος πίνακα")
("tables" "πίνακες")
("tabular" "πίνακας δεδομένων")
("tabular material" "υλικό σε μορφή πίνακα")
("tags with special rendering" "ετικέτες με ειδική απόδοση")
("tangent" "εφαπτομένη")
("teXmacs DTD" "teXmacs DTD")
("teXmacs as an interface" "το teXmacs ως διεπαφή")
("teXmacs buffer expected" "αναμενόμενο buffer TeXmacs")
("teXmacs buffer on disk expected" "αναμενόμενο buffer TeXmacs στο δίσκο")
("teXmacs extensions to scheme and utilities" "επεκτάσεις TeXmacs στο scheme και στα βοηθητικά προγράμματα")
("teXmacs fonts" "γραμματοσειρές του teXmacs")
("teXmacs macro" "μακροεντολή TeXmacs")
("teXmacs notice" "ανακοίνωση του teXmacs")
("teXmacs package" "πακέτο TeXmacs")
("teXmacs plugins" "plugins του teXmacs")
("teXmacs primitives" "teXmacs primitives")
("teXmacs style" "στυλ TeXmacs")
("teXmacs style files" "αρχεία στυλ του teXmacs")
("ternary" "τριτεύον")
("test" "δοκιμή")
("test routine" "ρουτίνα δοκιμής")
("testing tree-view" "έλεγχος προβολής δέντρου")
("tex" "tex")
("text" "κείμενο")
("text borders" "περιθώρια κειμένου")
("text box style" "στυλ πλαισίου κειμένου")
("text corners" "γωνίες κειμένου")
("text font" "γραμματοσειρά κειμένου")
("text height correction" "διόρθωση ύψους κειμένου")
("text width" "πλάτος κειμένου")
("texts" "κείμενα")
("textual" "κειμενικό")
("textual operator" "χειριστής κειμένου")
("textual spreadsheet" "υπολογιστικό φύλλο με κείμενο")
("th century bc" "ος αιώνας π.Χ.")
("th root" "-οστή ρίζα")
("thai" "ταϋλανδικά")
("the TeXmacs authors" "οι συγγραφείς του TeXmacs")
("the TeXmacs format" "η μορφή του TeXmacs")
("the TeXmacs plug-in system" "το σύστημα plug-in του TeXmacs")
("the application did not send its usual startup banner" "η εφαρμογή δεν έστειλε το συνηθισμένο αρχικό λογότυπο")
("the application does not reply" "η εφαρμογή δεν ανταποκρίνεται")
("the application is already running" "η εφαρμογή είναι ήδη σε λειτουργία")
("the boxes produced by the typesetter" "τα πλαίσια που παράγονται από τον στοιχειοθέτη")
("the document has not been saved" "η προσωρινή αποθήκευση δεν έχει αποθηκευτεί")
("the graphical user interface" "η γραφική διεπαφή με τον χρήστη")
("the leaves of TeXmacs trees" "τα φύλλα του δένδρου του TeXmacs")
("the mycas example" "το παράδειγμα του mycas")
("the primitive TeXmacs constructs" "οι αρχέτυπες δομές του TeXmacs")
("the standard TeXmacs styles" "τα τυπικά στυλ του ΤeXmacs")
("theme parameters" "παράμετροι θέματος")
("theorem" "θεώρημα")
("there are unsaved documents" "υπάρχουν μη αποθηκευμένα αρχεία")
("these collected public keys will be definitely lost" "αυτά τα συλλεγμένα δημόσια κλειδιά θα χαθούν σίγουρα")
("these public keys will be definitely lost" "αυτά τα δημόσια κλειδιά θα χαθούν σίγουρα")
("these secret keys will be definitely lost" "αυτά τα μυστικά κλειδιά θα χαθούν σίγουρα")
("thicken" "πάχος")
("third" "τρίτο")
("this" "αυτό")
("this column" "αυτή η στήλη")
("this document has been produced using" "αυτό το έγγραφο έχει παραχθεί με")
("this document has not been saved" "αυτη η προσωρινή αποθήκευση δεν έχει αποθηκευθεί")
("this line" "αυτή η γραμμή")
("this page" "αυτή η σελίδα")
("this page footer" "το υποσέλιδο αυτής της σελίδας")
("this page header" "η κεφαλίδα αυτής της σελίδας")
("this page number" "αυτός ο αριθμός σελίδας")
("this row" "αυτή η σειρά")
("this style specifies page margins in the TeX way" "αυτό το στυλ καθορίζει τα περιθώρια της σελίδας με τον τρόπο TeX")
("three columns" "τρεις στήλες")
("three dots" "τρεις κουκκίδες")
("through popup windows" "μέσω αναδυόμενων παραθύρων")
("through the menus" "μέσω των μενού")
("thumbnails" "μικρογραφίες")
("tilda" "tilda")
("tilde" "περισπωμένη")
("time evolution" "εξέλιξη χρόνου")
("times" "times")
("timings" "χρονισμοί")
("tiny" "μικροσκοπικό")
("title" "τίτλος")
("title presentation options" "επιλογές παρουσίασης τίτλου")
("title style" "στυλ τίτλου")
("title suffix" "επίθημα τίτλου")
("titled block" "απόσπασμα με τίτλο")
("to the left" "στα αριστερά")
("to the right" "στα δεξιά")
("today" "σήμερα")
("toggle cell wrapping mode" "εναλλαγή τρόπου αναδίπλωσης κελιών")
("toggle here" "εναλλαγή εδώ")
("toggle off" "παύση εναλλαγής")
("toggle on" "ενεργοποίηση εναλλαγής")
("tolerant" "ανεκτικό")
("tools" "εργαλεία")
("top" "πάνω")
("top baseline" "βασική γραμμή στο πάνω μέρος")
("top border" "πάνω περίγραμμα")
("top cell border" "πάνω περίγραμμα κελιού")
("top cell padding" "πάνω αναπλήρωση κελιού")
("top level" "πάνω επίπεδο")
("top margin" "πάνω περιθώριο")
("top padding" "πάνω αναπλήρωση")
("top table border" "πάνω περίγραμμα πίνακα")
("top table padding" "γέμισμα στο πάνω μέρος του πίνακα")
("transcendental functions" "υπερβατικές συναρτήσεις")
("transform" "μετασχηματισμός")
("transform cell into subtable" "μετασχηματισμός κελιού σε υποπίνακα")
("transformations" "μετασχηματισμοί")
("translate" "μετάφραση")
("translations" "μεταφράσεις")
("translations loaded" "οι μεταφράσεις φορτώθηκαν")
("transpose" "transpose")
("traversal" "διάσχιση")
("traverse" "περιφορά")
("tree" "δένδρο")
("triangle" "τρίγωνο")
("triangularize" "τριγωνοποίηση")
("trigonometric" "τριγωνομετρικό")
("trigonometric functions" "τριγωνομετρικές συναρτήσεις")
("trigonometric rewriting" "τριγωνομετρική επανεγγραφή")
("trigonometry" "τριγωνομετρία")
("tuple" "πλειάδα")
("turkish" "τουρκικά")
("turn off" "απενεργοποίηση")
("turn on" "ενεργοποίηση")
("tutorial" "οδηγός εκμάθησης")
("two columns" "δύο στήλες")
("two dots" "δύο κουκκίδες")
("type" "πληκτρολόγηση")
("type a latex command followed by" "πληκτρολόγηση εντολής latex ακολουθούμενης από")
("type a latex command followed by return" "πληκτρολογήστε μια εντολή latex και στην συνέχεια  πατήστε return")
("type body" "πληκτρολόγηση σώματος")
("type denominator" "πληκτρολόγηση παρονομαστή")
("type numerator" "πληκτρολόγηση ονομαστή")
("type script" "πληκτρολόγηση script")
("typesetted boxes" "στοιχειοθετημένα πλαίσια")
("typewriter" "typewriter")
("typewriter small caps" "καπιταλάκια σε typewriter")
("typing a simple text" "πληκτρολόγηση απλού κειμένου")
("typing simple texts" "πληκτρολόγηση απλών κειμένων")
("ugaritic" "ugaritic")
("ukrainian" "ουκρανικά")
("underbrace" "αγκύλη έκτασης από κάτω")
("underline" "υπογράμμιση")
("underlined" "υπογραμμισμένο")
("undo" "αναίρεση ενέργειας")
("undo last changes" "αναίρεση τελευταίων αλλαγών")
("unevaluated argument" " μη αποτιμημένο όρισμα")
("unevaluated value" "μη αποτιμημένο κόστος")
("unfold" "ξεδιπλώστε")
("unfold all" "ξεδιπλώστε όλα")
("unfold all fields" "ξεδίπλωμα όλων των πεδίων")
("unit" "μονάδα")
("unit length" "μονάδα μήκους")
("unknown secret key fingerprint" "άγνωστο δακτυλικό αποτύπωμα μυστικού κλειδιού")
("unregistered file" "μη καταχωρημένο αρχείο")
("unroll" "ξετύλιγμα")
("unsecure script refused" "μη ασφαλής δέσμη ενεργειών απορρίφθηκε")
("unsupported link mode" "μη υποστηριζόμενη λειτουργία σύνδεσης")
("until" "μέχρι")
("untitled block" "μπλοκ χωρίς τίτλο")
("up" "πάνω")
("up to date" "ενημερωμένα")
("update" "ανανέωση")
("update buffer" "ενημέρωση buffer")
("update from web" "ανανέωση από το διαδίκτυο")
("update image links" "ανανέωση συνδέσμων με εικόνες")
("update this buffer" "ενημέρωση αυτού του buffer")
("update web site" "ενημέρωση ιστοσελίδας")
("upight" "επάνω")
("upload" "ανέβασμα")
("upper border" "ανώτερο περίγραμμα")
("upright" "όρθια")
("upwards" "προς τα πάνω")
("use CSS for more advanced formatting" "χρήση CSS για πιο προηγμένη μορφοποίηση")
("use MathML" "χρήση MathML")
("use TeXmacs" "χρήση TeXmacs")
("use a black color" "χρήση μαύρου χρώματος")
("use a blue color" "χρήση μπλε χρώματος")
("use a bold font" "χρήση γραμματοσειράς bold")
("use a brown color" "χρήση καφέ χρώματος")
("use a calligraphic font" "χρήση γραμματοσειράς calligraphic")
("use a green color" "χρήση πράσινου χρώματος")
("use a grey color" "χρήση γκρι χρώματος")
("use a magenta color" "χρήση μωβ χρώματος")
("use a orange color" "χρήση πορτοκαλί χρώματος")
("use a pink color" "χρήση ροζ χρώματος")
("use a red color" "χρήση κόκκινου χρώματος")
("use a sans serif font" "χρήση γραμματοσειράς sans serif")
("use a typewriter font" "χρήση γραμματοσειράς typewriter")
("use a white color" "χρήση λευκού χρώματος")
("use a yellow color" "χρήση κίτρινου χρώματος")
("use as master" "χρήση ως πρωτότυπο")
("use blackboard bold font" "χρήση γραμματοσειράς blackboard bold")
("use bold font series" "χρήση γραμματοσειράς bold")
("use calligraphical font" "χρήση γραμματοσειράς calligraphic")
("use extensible brackets" "χρήση επεκτάσιμων αγκύλων")
("use footnote font size" "χρήση μεγέθους γραμματοσειράς για υποσημειώσεις")
("use fraktur font" "χρήση γραμματοσειράς fraktur")
("use huge font size" "χρήση τεράστιου μεγέθους γραμματοσειράς")
("use italic font shape" "χρήση σχήματος italic γραμματοσειράς")
("use large font size" "χρήση μεγάλου μεγέθους γραμματοσειράς")
("use left hand column as border" "χρήση αριστερής στήλης ως περίγραμμα")
("use line wrapping for lines which are longer than 80 characters" "χρήση αναδίπλωσης γραμμής για γραμμές μεγαλύτερες των 80 χαρακτήρων")
("use margin kerning (protrusion)" "χρήση περιθωρίου σύμπτυξης (προεξοχή)")
("use medium font series" "χρήση γραμματοσειράς μεσαίου μεγέθους")
("use normal font size" "χρήση γραμματοσειράς κανονικού μεγέθους")
("use package" "χρήση πακέτου")
("use paragraph width" "χρήση πλάτους παραγράφου")
("use protrusion" "χρήση προεξοχής")
("use really huge font size" "χρήση πραγματικά τεραστίου μεγέθους της γραμματοσειράς")
("use relative path" "χρήση σχετικής διαδρομής")
("use right font shape" "χρήση ορθού σχήματος της γραμματοσειράς")
("use right hand column as border" "χρήση δεξιάς στήλης ως περίγραμμα")
("use roman font family" "χρήση οικογένειας roman της γραμματοσειράς")
("use row above as border" "χρήση πάνω σειράς ως περίγραμμα")
("use row below as border" "χρήση κάτω σειράς ως περίγραμμα")
("use sans serif font family" "χρήση οικογένειας sans serif της γραμματοσειράς")
("use script font size" "χρήση μεγέθους script της γραμματοσειράς")
("use slanted font shape" "χρήση κεκλιμένου σχήματος της γραμματοσειράς")
("use small capitals" "χρήση μικρών κεφαλαίων")
("use small font size" "χρήση μικρού μεγέθους της γραμματοσειράς")
("use small-caps font shape" "χρήση σχήματος καπιταλάκια της γραμματοσειράς")
("use the blackboard bold font" "χρήση blackboard bold της γραμματοσειράς")
("use the fraktur font" "χρήση της γραμματοσειράς fraktur")
("use tiny font font size" "χρήση μικροσκοπικού μεγέθους της γραμματοσειράς")
("use typewriter font family" "χρήση οικογένειας typewriter της γραμματοσειράς")
("use very large font size" "χρήση πολύ μεγάλου μεγέθους της γραμματοσειράς")
("user interface" "διεπαφή χρήστη")
("user interface language" "γλώσσα διεπαφής χρήστη")
("user manual" "εγχειρίδιο χρήσης")
("user preferences" "προτιμήσεις χρήστη")
("user provided icons" "εικονίδια που παρέχονται από τον χρήστη")
("users of Cyrillic languages" "χρήστες κυριλλικών γλωσσών")
("users of oriental languages" "χρήστες ανατολικών γλωσσών")
("utf-8 with inputenc LaTeX package" "πακέτο LaTeX Utf-8 με inputenc")
("utilities" "βοηθητικά προγράμματα")
("value" "τιμή")
("vanish" "εξαφάνιση")
("variable" "μεταβλητή")
("variant" "παραλλαγή")
("vector" "διάνυσμα")
("verbatim" "verbatim")
("verbose" "verbose")
("verse" "εδάφιο")
("version" "έκδοση")
("versioning tool" "εργαλείο εκδόσεων")
("vertical" "κατακόρυφα")
("vertical after" "κατακόρυφα μετά")
("vertical alignment" "κατακόρυφη στοίχιση")
("vertical before" "κατακόρυφα πριν")
("vertical cell alignment" "κατακόρυφη στοίχιση κελιού")
("vertical margins" "κατακόρυφα περιθώρια")
("vertical part" "κατακόρυφο τμήμα")
("vertical position" "κατακόρυφη θέση")
("vertical space" "κατακόρυφο διάστημα")
("vertical space after" "κατακόρυφο διάστημα μετά")
("vertical space before" "κατακόρυφο διάστημα πριν")
("vertical space stretchability" "κατακόρυφη ελαστικότητα χώρου")
("vertical table alignment" "κατακόρυφη στοίχιση πίνακα")
("vertically align cell to the base" "κατακόρυφη στοίχιση κελιού στη βάση")
("vertically center the cell" "κατακόρυφο κεντράρισμα του κελιού")
("very large" "πολύ μεγάλο")
("very small" "πολύ μικρό")
("vietnamese" "βιετναμέζικα")
("view" "επισκόπηση")
("visible" "ορατό")
("visible except here" "ορατά εκτός από εδώ")
("visible from here on" "ορατό από εδώ και πέρα")
("visible only here" "ορατό μόνο εδώ")
("visible until here" "ορατά μέχρι εδώ")
("visited loci" "επισκέφθηκαν τόπους")
("wallet" "πορτοφόλι")
("warning" "προειδοποίηση")
("wave" "κύμα")
("web" "διαδίκτυο")
("weight" "βάρος")
("welcome" "καλωσήλθατε")
("welcome to GNU TeXmacs" "καλωσήλθατε στο GNU TeXmacs")
("what is new" "τι νέο")
("when finished" "στο τέλος")
("when line wrapping" "όταν αναδιπλώνεται η γραμμή")
("while" "while")
("white" "λευκό")
("whitespace" "κενό διάστημα")
("wide" "ευρύ")
("wide accent" "πλατύς τόνος")
("wide bar" "πλατιά γραμμή")
("wide block" "ευρύ απόσπασμα")
("wide colored" "ευρεία έγχρωμη")
("wide float" "ευρύ αιωρούμενο")
("wide footnote" "Ευρεία υποσημείωση")
("wide tabular" "ευρύς πίνακας")
("widescreen" "ευρεία οθόνη")
("width" "πλάτος")
("width is exactly the specified width" "το πλάτος είναι ακριβώς το καθορισμένο")
("width is maximum of specified width and box width" "το πλάτος είναι το μέγιστο από: το καθορισμένο και το πλάτος πλαισίου")
("width is minimum of specified width and box width" "το πλάτος είναι το ελάχιστο από: το καθορισμένο και το πλάτος πλαισίου")
("width magnification" "μεγένθυνση πλάτους")
("window" "παράθυρο")
("window height" "ύψος παραθύρου")
("window width" "πλάτος παραθύρου")
("windows key" "πλήκτρο των Windows")
("with" "με")
("wrap lines" "αναδίπλωση γραμμών")
("write a macro" "γραφή μακροεντολής")
("write a name" "γραφή ονόματος")
("write bold mathematics" "γραφή μαθηματικών σε bold")
("write bold text" "γραφή κειμένου σε bold")
("write italic text" "γραφή κειμένου σε italic")
("write sample text" "γραφή δείγματος κειμένου")
("write strong text" "γραφή κειμένου σε strong")
("write typewriter text" "γραφή κειμένου σε typewriter")
("write verbatim text" "γραφή κειμένου σε verbatim")
("writing TeXmacs bibliography styles" "γράφοντας στυλ βιβλιογραφίας TeXmacs")
("writing data converters" "γραφή μετατροπέων δεδομένων")
("writing documentation" "γράφοντας τεκμηρίωση")
("writing your own style files" "γραφή των δικών σας αρχείων στυλ")
("written with TeXmacs" "γραμμένο με το TeXmacs")
("wrong empty passphrase" "λάθος κενή φράση πρόσβασης")
("wrong passphrase" "λανθασμένη φράση πρόσβασης")
("year" "έτος")
("yellow" "κίτρινο")
("you are attempting to open an encrypted file while" "προσπάθεια ανοίγματος κρυπτογραφημένου αρχείου ενώ")
("you can also obtain" "μπορείτε επίσης να αποκτήσετε")
("you might consider enabling the experimental" "μπορείτε να εξετάσετε το ενδεχόμενο ενεργοποίησης του πειραματικού")
("you must add a bibliography file" "πρέπει να προσθέσετε ένα αρχείο βιβλιογραφίας")
("you should also make sure that GnuPG is installed" "θα πρέπει επίσης να βεβαιωθείτε ότι το GnuPG είναι εγκατεστημένο")
("your document is back in its original state" "το έγγραφό σας επανήλθε στην αρχική του κατάσταση")
("your first interface" "η πρώτη σας διεπαφή")
("your language" "η γλώσσα σας")
("your personal dictionary has been modified" "το προσωπικό λεξικό σας έχει τροποποιηθεί")
("zoom" "ζουμ")
("zoom in" "μεγέθυνση")
("zoom out" "σμίκρυνση")
